// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: pkg/sentry/seccheck/points/syscall.proto
// Protobuf C++ Version: 7.34.1

#include "pkg/sentry/seccheck/points/syscall.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
namespace gvisor {
namespace syscall {

inline constexpr Timespec::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        sec_{::int64_t{0}},
        nsec_{::int64_t{0}} {}

template <typename>
constexpr Timespec::Timespec(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Timespec_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct TimespecDefaultTypeInternal {
  constexpr TimespecDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~TimespecDefaultTypeInternal() {}
  union {
    Timespec _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 TimespecDefaultTypeInternal _Timespec_default_instance_;

inline constexpr StructRlimit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        cur_{::uint64_t{0u}},
        max_{::uint64_t{0u}} {}

template <typename>
constexpr StructRlimit::StructRlimit(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(StructRlimit_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct StructRlimitDefaultTypeInternal {
  constexpr StructRlimitDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~StructRlimitDefaultTypeInternal() {}
  union {
    StructRlimit _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 StructRlimitDefaultTypeInternal _StructRlimit_default_instance_;

inline constexpr Exit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        result_{::int64_t{0}},
        errorno_{::int64_t{0}} {}

template <typename>
constexpr Exit::Exit(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Exit_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ExitDefaultTypeInternal {
  constexpr ExitDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ExitDefaultTypeInternal() {}
  union {
    Exit _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ExitDefaultTypeInternal _Exit_default_instance_;

inline constexpr ItimerSpec::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        interval_{nullptr},
        value_{nullptr} {}

template <typename>
constexpr ItimerSpec::ItimerSpec(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(ItimerSpec_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ItimerSpecDefaultTypeInternal {
  constexpr ItimerSpecDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ItimerSpecDefaultTypeInternal() {}
  union {
    ItimerSpec _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ItimerSpecDefaultTypeInternal _ItimerSpec_default_instance_;

inline constexpr Write::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{::int64_t{0}},
        count_{::uint64_t{0u}},
        offset_{::int64_t{0}},
        has_offset_{false},
        flags_{0u} {}

template <typename>
constexpr Write::Write(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Write_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct WriteDefaultTypeInternal {
  constexpr WriteDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~WriteDefaultTypeInternal() {}
  union {
    Write _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 WriteDefaultTypeInternal _Write_default_instance_;

inline constexpr TimerfdSetTime::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        new_value_{nullptr},
        old_value_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0},
        flags_{0} {}

template <typename>
constexpr TimerfdSetTime::TimerfdSetTime(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(TimerfdSetTime_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct TimerfdSetTimeDefaultTypeInternal {
  constexpr TimerfdSetTimeDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~TimerfdSetTimeDefaultTypeInternal() {}
  union {
    TimerfdSetTime _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 TimerfdSetTimeDefaultTypeInternal _TimerfdSetTime_default_instance_;

inline constexpr TimerfdGetTime::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        cur_value_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0} {}

template <typename>
constexpr TimerfdGetTime::TimerfdGetTime(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(TimerfdGetTime_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct TimerfdGetTimeDefaultTypeInternal {
  constexpr TimerfdGetTimeDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~TimerfdGetTimeDefaultTypeInternal() {}
  union {
    TimerfdGetTime _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 TimerfdGetTimeDefaultTypeInternal _TimerfdGetTime_default_instance_;

inline constexpr TimerfdCreate::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        clock_id_{0},
        flags_{0} {}

template <typename>
constexpr TimerfdCreate::TimerfdCreate(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(TimerfdCreate_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct TimerfdCreateDefaultTypeInternal {
  constexpr TimerfdCreateDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~TimerfdCreateDefaultTypeInternal() {}
  union {
    TimerfdCreate _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 TimerfdCreateDefaultTypeInternal _TimerfdCreate_default_instance_;

inline constexpr Syscall::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        arg1_{::uint64_t{0u}},
        arg2_{::uint64_t{0u}},
        arg3_{::uint64_t{0u}},
        arg4_{::uint64_t{0u}},
        arg5_{::uint64_t{0u}},
        arg6_{::uint64_t{0u}} {}

template <typename>
constexpr Syscall::Syscall(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Syscall_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct SyscallDefaultTypeInternal {
  constexpr SyscallDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~SyscallDefaultTypeInternal() {}
  union {
    Syscall _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 SyscallDefaultTypeInternal _Syscall_default_instance_;

inline constexpr SocketPair::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        domain_{0},
        type_{0},
        protocol_{0},
        socket1_{0},
        socket2_{0} {}

template <typename>
constexpr SocketPair::SocketPair(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(SocketPair_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct SocketPairDefaultTypeInternal {
  constexpr SocketPairDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~SocketPairDefaultTypeInternal() {}
  union {
    SocketPair _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 SocketPairDefaultTypeInternal _SocketPair_default_instance_;

inline constexpr Socket::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        domain_{0},
        type_{0},
        protocol_{0} {}

template <typename>
constexpr Socket::Socket(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Socket_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct SocketDefaultTypeInternal {
  constexpr SocketDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~SocketDefaultTypeInternal() {}
  union {
    Socket _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 SocketDefaultTypeInternal _Socket_default_instance_;

inline constexpr Signalfd::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0},
        flags_{0},
        sigset_{::uint64_t{0u}} {}

template <typename>
constexpr Signalfd::Signalfd(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Signalfd_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct SignalfdDefaultTypeInternal {
  constexpr SignalfdDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~SignalfdDefaultTypeInternal() {}
  union {
    Signalfd _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 SignalfdDefaultTypeInternal _Signalfd_default_instance_;

inline constexpr Setresid::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        rid_{0u},
        eid_{0u},
        sid_{0u} {}

template <typename>
constexpr Setresid::Setresid(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Setresid_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct SetresidDefaultTypeInternal {
  constexpr SetresidDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~SetresidDefaultTypeInternal() {}
  union {
    Setresid _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 SetresidDefaultTypeInternal _Setresid_default_instance_;

inline constexpr Setid::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        id_{0u} {}

template <typename>
constexpr Setid::Setid(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Setid_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct SetidDefaultTypeInternal {
  constexpr SetidDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~SetidDefaultTypeInternal() {}
  union {
    Setid _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 SetidDefaultTypeInternal _Setid_default_instance_;

inline constexpr Read::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{::int64_t{0}},
        count_{::uint64_t{0u}},
        offset_{::int64_t{0}},
        has_offset_{false},
        flags_{0u} {}

template <typename>
constexpr Read::Read(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Read_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ReadDefaultTypeInternal {
  constexpr ReadDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ReadDefaultTypeInternal() {}
  union {
    Read _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ReadDefaultTypeInternal _Read_default_instance_;

inline constexpr Prlimit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        new_limit_{nullptr},
        old_limit_{nullptr},
        sysno_{::uint64_t{0u}},
        resource_{::int64_t{0}},
        pid_{0} {}

template <typename>
constexpr Prlimit::Prlimit(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Prlimit_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct PrlimitDefaultTypeInternal {
  constexpr PrlimitDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~PrlimitDefaultTypeInternal() {}
  union {
    Prlimit _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PrlimitDefaultTypeInternal _Prlimit_default_instance_;

inline constexpr Pipe::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        flags_{0u},
        reader_{0},
        writer_{0} {}

template <typename>
constexpr Pipe::Pipe(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Pipe_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct PipeDefaultTypeInternal {
  constexpr PipeDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~PipeDefaultTypeInternal() {}
  union {
    Pipe _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PipeDefaultTypeInternal _Pipe_default_instance_;

inline constexpr Open::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        pathname_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{::int64_t{0}},
        flags_{0u},
        mode_{0u} {}

template <typename>
constexpr Open::Open(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Open_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct OpenDefaultTypeInternal {
  constexpr OpenDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~OpenDefaultTypeInternal() {}
  union {
    Open _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 OpenDefaultTypeInternal _Open_default_instance_;

inline constexpr InotifyRmWatch::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0},
        wd_{0} {}

template <typename>
constexpr InotifyRmWatch::InotifyRmWatch(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(InotifyRmWatch_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct InotifyRmWatchDefaultTypeInternal {
  constexpr InotifyRmWatchDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~InotifyRmWatchDefaultTypeInternal() {}
  union {
    InotifyRmWatch _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 InotifyRmWatchDefaultTypeInternal _InotifyRmWatch_default_instance_;

inline constexpr InotifyInit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        flags_{0} {}

template <typename>
constexpr InotifyInit::InotifyInit(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(InotifyInit_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct InotifyInitDefaultTypeInternal {
  constexpr InotifyInitDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~InotifyInitDefaultTypeInternal() {}
  union {
    InotifyInit _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 InotifyInitDefaultTypeInternal _InotifyInit_default_instance_;

inline constexpr InotifyAddWatch::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        pathname_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0},
        mask_{0u} {}

template <typename>
constexpr InotifyAddWatch::InotifyAddWatch(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(InotifyAddWatch_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct InotifyAddWatchDefaultTypeInternal {
  constexpr InotifyAddWatchDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~InotifyAddWatchDefaultTypeInternal() {}
  union {
    InotifyAddWatch _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 InotifyAddWatchDefaultTypeInternal _InotifyAddWatch_default_instance_;

inline constexpr Fork::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}} {}

template <typename>
constexpr Fork::Fork(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Fork_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ForkDefaultTypeInternal {
  constexpr ForkDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ForkDefaultTypeInternal() {}
  union {
    Fork _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ForkDefaultTypeInternal _Fork_default_instance_;

inline constexpr Fcntl::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0},
        cmd_{0},
        args_{::int64_t{0}} {}

template <typename>
constexpr Fcntl::Fcntl(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Fcntl_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct FcntlDefaultTypeInternal {
  constexpr FcntlDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~FcntlDefaultTypeInternal() {}
  union {
    Fcntl _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 FcntlDefaultTypeInternal _Fcntl_default_instance_;

inline constexpr Execve::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        argv_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::gvisor::syscall::Execve,
            PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.argv_)>()
        }
        #else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        argv_ {}
        #endif
        ,
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        envv_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::gvisor::syscall::Execve,
            PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.envv_)>()
        }
        #else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        envv_ {}
        #endif
        ,
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        pathname_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{::int64_t{0}},
        flags_{0u} {}

template <typename>
constexpr Execve::Execve(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Execve_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ExecveDefaultTypeInternal {
  constexpr ExecveDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ExecveDefaultTypeInternal() {}
  union {
    Execve _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ExecveDefaultTypeInternal _Execve_default_instance_;

inline constexpr Eventfd::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        val_{0},
        flags_{0u} {}

template <typename>
constexpr Eventfd::Eventfd(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Eventfd_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct EventfdDefaultTypeInternal {
  constexpr EventfdDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~EventfdDefaultTypeInternal() {}
  union {
    Eventfd _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 EventfdDefaultTypeInternal _Eventfd_default_instance_;

inline constexpr Dup::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        old_fd_{0},
        new_fd_{0},
        flags_{0u} {}

template <typename>
constexpr Dup::Dup(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Dup_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct DupDefaultTypeInternal {
  constexpr DupDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~DupDefaultTypeInternal() {}
  union {
    Dup _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 DupDefaultTypeInternal _Dup_default_instance_;

inline constexpr Connect::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        address_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{::int64_t{0}} {}

template <typename>
constexpr Connect::Connect(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Connect_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ConnectDefaultTypeInternal {
  constexpr ConnectDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ConnectDefaultTypeInternal() {}
  union {
    Connect _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ConnectDefaultTypeInternal _Connect_default_instance_;

inline constexpr Close::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{::int64_t{0}} {}

template <typename>
constexpr Close::Close(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Close_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct CloseDefaultTypeInternal {
  constexpr CloseDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~CloseDefaultTypeInternal() {}
  union {
    Close _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 CloseDefaultTypeInternal _Close_default_instance_;

inline constexpr Clone::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        flags_{::uint64_t{0u}},
        stack_{::uint64_t{0u}},
        new_tid_{::uint64_t{0u}},
        tls_{::uint64_t{0u}} {}

template <typename>
constexpr Clone::Clone(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Clone_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct CloneDefaultTypeInternal {
  constexpr CloneDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~CloneDefaultTypeInternal() {}
  union {
    Clone _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 CloneDefaultTypeInternal _Clone_default_instance_;

inline constexpr Chroot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        pathname_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}} {}

template <typename>
constexpr Chroot::Chroot(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Chroot_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ChrootDefaultTypeInternal {
  constexpr ChrootDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ChrootDefaultTypeInternal() {}
  union {
    Chroot _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ChrootDefaultTypeInternal _Chroot_default_instance_;

inline constexpr Chdir::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        pathname_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{::int64_t{0}} {}

template <typename>
constexpr Chdir::Chdir(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Chdir_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct ChdirDefaultTypeInternal {
  constexpr ChdirDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ChdirDefaultTypeInternal() {}
  union {
    Chdir _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ChdirDefaultTypeInternal _Chdir_default_instance_;

inline constexpr Bind::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        address_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0} {}

template <typename>
constexpr Bind::Bind(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Bind_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct BindDefaultTypeInternal {
  constexpr BindDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~BindDefaultTypeInternal() {}
  union {
    Bind _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 BindDefaultTypeInternal _Bind_default_instance_;

inline constexpr Accept::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        fd_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        address_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        context_data_{nullptr},
        exit_{nullptr},
        sysno_{::uint64_t{0u}},
        fd_{0},
        flags_{0} {}

template <typename>
constexpr Accept::Accept(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(Accept_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
struct AcceptDefaultTypeInternal {
  constexpr AcceptDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~AcceptDefaultTypeInternal() {}
  union {
    Accept _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 AcceptDefaultTypeInternal _Accept_default_instance_;
}  // namespace syscall
}  // namespace gvisor
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto = nullptr;
const ::uint32_t
    TableStruct_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Exit, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Exit, _impl_.result_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Exit, _impl_.errorno_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_._has_bits_),
        12, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.arg1_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.arg2_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.arg3_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.arg4_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.arg5_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Syscall, _impl_.arg6_),
        0,
        1,
        2,
        3,
        4,
        5,
        6,
        7,
        8,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_._has_bits_),
        11, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.pathname_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.flags_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Open, _impl_.mode_),
        2,
        3,
        4,
        5,
        0,
        1,
        6,
        7,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Close, _impl_._has_bits_),
        8, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Close, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Close, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Close, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Close, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Close, _impl_.fd_path_),
        1,
        2,
        3,
        4,
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_._has_bits_),
        12, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.count_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.has_offset_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.offset_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Read, _impl_.flags_),
        1,
        2,
        3,
        4,
        0,
        5,
        7,
        6,
        8,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_._has_bits_),
        12, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.count_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.has_offset_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.offset_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Write, _impl_.flags_),
        1,
        2,
        3,
        4,
        0,
        5,
        7,
        6,
        8,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Connect, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Connect, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Connect, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Connect, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Connect, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Connect, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Connect, _impl_.address_),
        2,
        3,
        4,
        5,
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_._has_bits_),
        12, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.pathname_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.argv_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.envv_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.flags_),
        4,
        5,
        6,
        7,
        2,
        3,
        0,
        1,
        8,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Socket, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Socket, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Socket, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Socket, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Socket, _impl_.domain_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Socket, _impl_.type_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Socket, _impl_.protocol_),
        0,
        1,
        2,
        3,
        4,
        5,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chdir, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chdir, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chdir, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chdir, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chdir, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chdir, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chdir, _impl_.pathname_),
        2,
        3,
        4,
        5,
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setresid, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setresid, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setresid, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setresid, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setresid, _impl_.rid_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setresid, _impl_.eid_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setresid, _impl_.sid_),
        0,
        1,
        2,
        3,
        4,
        5,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setid, _impl_._has_bits_),
        7, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setid, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setid, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setid, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Setid, _impl_.id_),
        0,
        1,
        2,
        3,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::StructRlimit, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::StructRlimit, _impl_.cur_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::StructRlimit, _impl_.max_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_.pid_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_.resource_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_.new_limit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Prlimit, _impl_.old_limit_),
        0,
        1,
        4,
        6,
        5,
        2,
        3,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Pipe, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Pipe, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Pipe, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Pipe, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Pipe, _impl_.flags_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Pipe, _impl_.reader_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Pipe, _impl_.writer_),
        0,
        1,
        2,
        3,
        4,
        5,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_.cmd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fcntl, _impl_.args_),
        1,
        2,
        3,
        4,
        0,
        5,
        6,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_.old_fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_.new_fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Dup, _impl_.flags_),
        1,
        2,
        3,
        4,
        5,
        0,
        6,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_.sigset_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Signalfd, _impl_.flags_),
        1,
        2,
        3,
        4,
        0,
        6,
        5,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chroot, _impl_._has_bits_),
        7, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chroot, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chroot, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chroot, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Chroot, _impl_.pathname_),
        1,
        2,
        3,
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Eventfd, _impl_._has_bits_),
        8, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Eventfd, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Eventfd, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Eventfd, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Eventfd, _impl_.val_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Eventfd, _impl_.flags_),
        0,
        1,
        2,
        3,
        4,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_.flags_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_.stack_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_.new_tid_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Clone, _impl_.tls_),
        0,
        1,
        2,
        3,
        4,
        5,
        6,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Bind, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Bind, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Bind, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Bind, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Bind, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Bind, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Bind, _impl_.address_),
        2,
        3,
        4,
        5,
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_.address_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Accept, _impl_.flags_),
        2,
        3,
        4,
        5,
        0,
        1,
        6,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdCreate, _impl_._has_bits_),
        8, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdCreate, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdCreate, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdCreate, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdCreate, _impl_.clock_id_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdCreate, _impl_.flags_),
        0,
        1,
        2,
        3,
        4,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Timespec, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Timespec, _impl_.sec_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Timespec, _impl_.nsec_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::ItimerSpec, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::ItimerSpec, _impl_.interval_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::ItimerSpec, _impl_.value_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_._has_bits_),
        11, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.flags_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.new_value_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdSetTime, _impl_.old_value_),
        1,
        2,
        5,
        6,
        0,
        7,
        3,
        4,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdGetTime, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdGetTime, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdGetTime, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdGetTime, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdGetTime, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdGetTime, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::TimerfdGetTime, _impl_.cur_value_),
        1,
        2,
        4,
        5,
        0,
        3,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fork, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fork, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fork, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Fork, _impl_.sysno_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyInit, _impl_._has_bits_),
        7, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyInit, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyInit, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyInit, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyInit, _impl_.flags_),
        0,
        1,
        2,
        3,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_.pathname_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyAddWatch, _impl_.mask_),
        2,
        3,
        4,
        5,
        0,
        1,
        6,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyRmWatch, _impl_._has_bits_),
        9, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyRmWatch, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyRmWatch, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyRmWatch, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyRmWatch, _impl_.fd_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyRmWatch, _impl_.fd_path_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::InotifyRmWatch, _impl_.wd_),
        1,
        2,
        3,
        4,
        0,
        5,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_._has_bits_),
        11, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.context_data_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.exit_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.sysno_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.domain_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.type_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.protocol_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.socket1_),
        PROTOBUF_FIELD_OFFSET(::gvisor::syscall::SocketPair, _impl_.socket2_),
        0,
        1,
        2,
        3,
        4,
        5,
        6,
        7,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::gvisor::syscall::Exit)},
        {7, sizeof(::gvisor::syscall::Syscall)},
        {28, sizeof(::gvisor::syscall::Open)},
        {47, sizeof(::gvisor::syscall::Close)},
        {60, sizeof(::gvisor::syscall::Read)},
        {81, sizeof(::gvisor::syscall::Write)},
        {102, sizeof(::gvisor::syscall::Connect)},
        {117, sizeof(::gvisor::syscall::Execve)},
        {138, sizeof(::gvisor::syscall::Socket)},
        {153, sizeof(::gvisor::syscall::Chdir)},
        {168, sizeof(::gvisor::syscall::Setresid)},
        {183, sizeof(::gvisor::syscall::Setid)},
        {194, sizeof(::gvisor::syscall::StructRlimit)},
        {201, sizeof(::gvisor::syscall::Prlimit)},
        {218, sizeof(::gvisor::syscall::Pipe)},
        {233, sizeof(::gvisor::syscall::Fcntl)},
        {250, sizeof(::gvisor::syscall::Dup)},
        {267, sizeof(::gvisor::syscall::Signalfd)},
        {284, sizeof(::gvisor::syscall::Chroot)},
        {295, sizeof(::gvisor::syscall::Eventfd)},
        {308, sizeof(::gvisor::syscall::Clone)},
        {325, sizeof(::gvisor::syscall::Bind)},
        {340, sizeof(::gvisor::syscall::Accept)},
        {357, sizeof(::gvisor::syscall::TimerfdCreate)},
        {370, sizeof(::gvisor::syscall::Timespec)},
        {377, sizeof(::gvisor::syscall::ItimerSpec)},
        {384, sizeof(::gvisor::syscall::TimerfdSetTime)},
        {403, sizeof(::gvisor::syscall::TimerfdGetTime)},
        {418, sizeof(::gvisor::syscall::Fork)},
        {427, sizeof(::gvisor::syscall::InotifyInit)},
        {438, sizeof(::gvisor::syscall::InotifyAddWatch)},
        {455, sizeof(::gvisor::syscall::InotifyRmWatch)},
        {470, sizeof(::gvisor::syscall::SocketPair)},
};
static const ::_pb::Message* PROTOBUF_NONNULL const file_default_instances[] = {
    &::gvisor::syscall::_Exit_default_instance_._instance,
    &::gvisor::syscall::_Syscall_default_instance_._instance,
    &::gvisor::syscall::_Open_default_instance_._instance,
    &::gvisor::syscall::_Close_default_instance_._instance,
    &::gvisor::syscall::_Read_default_instance_._instance,
    &::gvisor::syscall::_Write_default_instance_._instance,
    &::gvisor::syscall::_Connect_default_instance_._instance,
    &::gvisor::syscall::_Execve_default_instance_._instance,
    &::gvisor::syscall::_Socket_default_instance_._instance,
    &::gvisor::syscall::_Chdir_default_instance_._instance,
    &::gvisor::syscall::_Setresid_default_instance_._instance,
    &::gvisor::syscall::_Setid_default_instance_._instance,
    &::gvisor::syscall::_StructRlimit_default_instance_._instance,
    &::gvisor::syscall::_Prlimit_default_instance_._instance,
    &::gvisor::syscall::_Pipe_default_instance_._instance,
    &::gvisor::syscall::_Fcntl_default_instance_._instance,
    &::gvisor::syscall::_Dup_default_instance_._instance,
    &::gvisor::syscall::_Signalfd_default_instance_._instance,
    &::gvisor::syscall::_Chroot_default_instance_._instance,
    &::gvisor::syscall::_Eventfd_default_instance_._instance,
    &::gvisor::syscall::_Clone_default_instance_._instance,
    &::gvisor::syscall::_Bind_default_instance_._instance,
    &::gvisor::syscall::_Accept_default_instance_._instance,
    &::gvisor::syscall::_TimerfdCreate_default_instance_._instance,
    &::gvisor::syscall::_Timespec_default_instance_._instance,
    &::gvisor::syscall::_ItimerSpec_default_instance_._instance,
    &::gvisor::syscall::_TimerfdSetTime_default_instance_._instance,
    &::gvisor::syscall::_TimerfdGetTime_default_instance_._instance,
    &::gvisor::syscall::_Fork_default_instance_._instance,
    &::gvisor::syscall::_InotifyInit_default_instance_._instance,
    &::gvisor::syscall::_InotifyAddWatch_default_instance_._instance,
    &::gvisor::syscall::_InotifyRmWatch_default_instance_._instance,
    &::gvisor::syscall::_SocketPair_default_instance_._instance,
};
const char descriptor_table_protodef_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n(pkg/sentry/seccheck/points/syscall.pro"
    "to\022\016gvisor.syscall\032\'pkg/sentry/seccheck/"
    "points/common.proto\"\'\n\004Exit\022\016\n\006result\030\001 "
    "\001(\003\022\017\n\007errorno\030\002 \001(\003\"\302\001\n\007Syscall\0220\n\014cont"
    "ext_data\030\001 \001(\0132\032.gvisor.common.ContextDa"
    "ta\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r"
    "\n\005sysno\030\004 \001(\004\022\014\n\004arg1\030\005 \001(\004\022\014\n\004arg2\030\006 \001("
    "\004\022\014\n\004arg3\030\007 \001(\004\022\014\n\004arg4\030\010 \001(\004\022\014\n\004arg5\030\t "
    "\001(\004\022\014\n\004arg6\030\n \001(\004\"\267\001\n\004Open\0220\n\014context_da"
    "ta\030\001 \001(\0132\032.gvisor.common.ContextData\022\"\n\004"
    "exit\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r\n\005sysn"
    "o\030\003 \001(\004\022\n\n\002fd\030\004 \001(\003\022\017\n\007fd_path\030\005 \001(\t\022\020\n\010"
    "pathname\030\006 \001(\t\022\r\n\005flags\030\007 \001(\r\022\014\n\004mode\030\010 "
    "\001(\r\"\211\001\n\005Close\0220\n\014context_data\030\001 \001(\0132\032.gv"
    "isor.common.ContextData\022\"\n\004exit\030\002 \001(\0132\024."
    "gvisor.syscall.Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd"
    "\030\004 \001(\003\022\017\n\007fd_path\030\005 \001(\t\"\312\001\n\004Read\0220\n\014cont"
    "ext_data\030\001 \001(\0132\032.gvisor.common.ContextDa"
    "ta\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r"
    "\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\003\022\017\n\007fd_path\030\005 \001"
    "(\t\022\r\n\005count\030\006 \001(\004\022\022\n\nhas_offset\030\007 \001(\010\022\016\n"
    "\006offset\030\010 \001(\003\022\r\n\005flags\030\t \001(\r\"\313\001\n\005Write\0220"
    "\n\014context_data\030\001 \001(\0132\032.gvisor.common.Con"
    "textData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall."
    "Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\003\022\017\n\007fd_pa"
    "th\030\005 \001(\t\022\r\n\005count\030\006 \001(\004\022\022\n\nhas_offset\030\007 "
    "\001(\010\022\016\n\006offset\030\010 \001(\003\022\r\n\005flags\030\t \001(\r\"\234\001\n\007C"
    "onnect\0220\n\014context_data\030\001 \001(\0132\032.gvisor.co"
    "mmon.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor."
    "syscall.Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\003\022"
    "\017\n\007fd_path\030\005 \001(\t\022\017\n\007address\030\006 \001(\014\"\307\001\n\006Ex"
    "ecve\0220\n\014context_data\030\001 \001(\0132\032.gvisor.comm"
    "on.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.sy"
    "scall.Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\003\022\017\n"
    "\007fd_path\030\005 \001(\t\022\020\n\010pathname\030\006 \001(\t\022\014\n\004argv"
    "\030\007 \003(\t\022\014\n\004envv\030\010 \003(\t\022\r\n\005flags\030\t \001(\r\"\235\001\n\006"
    "Socket\0220\n\014context_data\030\001 \001(\0132\032.gvisor.co"
    "mmon.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor."
    "syscall.Exit\022\r\n\005sysno\030\003 \001(\004\022\016\n\006domain\030\004 "
    "\001(\005\022\014\n\004type\030\005 \001(\005\022\020\n\010protocol\030\006 \001(\005\"\233\001\n\005"
    "Chdir\0220\n\014context_data\030\001 \001(\0132\032.gvisor.com"
    "mon.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.s"
    "yscall.Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\003\022\017"
    "\n\007fd_path\030\005 \001(\t\022\020\n\010pathname\030\006 \001(\t\"\226\001\n\010Se"
    "tresid\0220\n\014context_data\030\001 \001(\0132\032.gvisor.co"
    "mmon.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor."
    "syscall.Exit\022\r\n\005sysno\030\003 \001(\004\022\013\n\003rid\030\004 \001(\r"
    "\022\013\n\003eid\030\005 \001(\r\022\013\n\003sid\030\006 \001(\r\"x\n\005Setid\0220\n\014c"
    "ontext_data\030\001 \001(\0132\032.gvisor.common.Contex"
    "tData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall.Exi"
    "t\022\r\n\005sysno\030\003 \001(\004\022\n\n\002id\030\004 \001(\r\"(\n\014StructRl"
    "imit\022\013\n\003cur\030\001 \001(\004\022\013\n\003max\030\002 \001(\004\"\357\001\n\007Prlim"
    "it\0220\n\014context_data\030\001 \001(\0132\032.gvisor.common"
    ".ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.sysc"
    "all.Exit\022\r\n\005sysno\030\003 \001(\004\022\013\n\003pid\030\004 \001(\005\022\020\n\010"
    "resource\030\005 \001(\003\022/\n\tnew_limit\030\006 \001(\0132\034.gvis"
    "or.syscall.StructRlimit\022/\n\told_limit\030\007 \001"
    "(\0132\034.gvisor.syscall.StructRlimit\"\232\001\n\004Pip"
    "e\0220\n\014context_data\030\001 \001(\0132\032.gvisor.common."
    "ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.sysca"
    "ll.Exit\022\r\n\005sysno\030\003 \001(\004\022\r\n\005flags\030\004 \001(\r\022\016\n"
    "\006reader\030\005 \001(\005\022\016\n\006writer\030\006 \001(\005\"\244\001\n\005Fcntl\022"
    "0\n\014context_data\030\001 \001(\0132\032.gvisor.common.Co"
    "ntextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall"
    ".Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_p"
    "ath\030\005 \001(\t\022\013\n\003cmd\030\006 \001(\005\022\014\n\004args\030\007 \001(\003\"\252\001\n"
    "\003Dup\0220\n\014context_data\030\001 \001(\0132\032.gvisor.comm"
    "on.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.sy"
    "scall.Exit\022\r\n\005sysno\030\003 \001(\004\022\016\n\006old_fd\030\004 \001("
    "\005\022\016\n\006new_fd\030\005 \001(\005\022\017\n\007fd_path\030\006 \001(\t\022\r\n\005fl"
    "ags\030\007 \001(\r\"\253\001\n\010Signalfd\0220\n\014context_data\030\001"
    " \001(\0132\032.gvisor.common.ContextData\022\"\n\004exit"
    "\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r\n\005sysno\030\003 "
    "\001(\004\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_path\030\005 \001(\t\022\016\n\006sigs"
    "et\030\006 \001(\004\022\r\n\005flags\030\007 \001(\005\"\177\n\006Chroot\0220\n\014con"
    "text_data\030\001 \001(\0132\032.gvisor.common.ContextD"
    "ata\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall.Exit\022"
    "\r\n\005sysno\030\003 \001(\004\022\020\n\010pathname\030\004 \001(\t\"\212\001\n\007Eve"
    "ntfd\0220\n\014context_data\030\001 \001(\0132\032.gvisor.comm"
    "on.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.sy"
    "scall.Exit\022\r\n\005sysno\030\003 \001(\004\022\013\n\003val\030\004 \001(\005\022\r"
    "\n\005flags\030\005 \001(\r\"\250\001\n\005Clone\0220\n\014context_data\030"
    "\001 \001(\0132\032.gvisor.common.ContextData\022\"\n\004exi"
    "t\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r\n\005sysno\030\003"
    " \001(\004\022\r\n\005flags\030\004 \001(\004\022\r\n\005stack\030\005 \001(\004\022\017\n\007ne"
    "w_tid\030\006 \001(\004\022\013\n\003tls\030\007 \001(\004\"\231\001\n\004Bind\0220\n\014con"
    "text_data\030\001 \001(\0132\032.gvisor.common.ContextD"
    "ata\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall.Exit\022"
    "\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_path\030\005 "
    "\001(\t\022\017\n\007address\030\006 \001(\014\"\252\001\n\006Accept\0220\n\014conte"
    "xt_data\030\001 \001(\0132\032.gvisor.common.ContextDat"
    "a\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r\n"
    "\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_path\030\005 \001("
    "\t\022\017\n\007address\030\006 \001(\014\022\r\n\005flags\030\007 \001(\005\"\225\001\n\rTi"
    "merfdCreate\0220\n\014context_data\030\001 \001(\0132\032.gvis"
    "or.common.ContextData\022\"\n\004exit\030\002 \001(\0132\024.gv"
    "isor.syscall.Exit\022\r\n\005sysno\030\003 \001(\004\022\020\n\010cloc"
    "k_id\030\004 \001(\005\022\r\n\005flags\030\005 \001(\005\"%\n\010Timespec\022\013\n"
    "\003sec\030\001 \001(\003\022\014\n\004nsec\030\002 \001(\003\"a\n\nItimerSpec\022*"
    "\n\010interval\030\001 \001(\0132\030.gvisor.syscall.Timesp"
    "ec\022\'\n\005value\030\002 \001(\0132\030.gvisor.syscall.Times"
    "pec\"\377\001\n\016TimerfdSetTime\0220\n\014context_data\030\001"
    " \001(\0132\032.gvisor.common.ContextData\022\"\n\004exit"
    "\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r\n\005sysno\030\003 "
    "\001(\004\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_path\030\005 \001(\t\022\r\n\005flag"
    "s\030\006 \001(\005\022-\n\tnew_value\030\007 \001(\0132\032.gvisor.sysc"
    "all.ItimerSpec\022-\n\told_value\030\010 \001(\0132\032.gvis"
    "or.syscall.ItimerSpec\"\301\001\n\016TimerfdGetTime"
    "\0220\n\014context_data\030\001 \001(\0132\032.gvisor.common.C"
    "ontextData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscal"
    "l.Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_"
    "path\030\005 \001(\t\022-\n\tcur_value\030\006 \001(\0132\032.gvisor.s"
    "yscall.ItimerSpec\"k\n\004Fork\0220\n\014context_dat"
    "a\030\001 \001(\0132\032.gvisor.common.ContextData\022\"\n\004e"
    "xit\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r\n\005sysno"
    "\030\003 \001(\004\"\201\001\n\013InotifyInit\0220\n\014context_data\030\001"
    " \001(\0132\032.gvisor.common.ContextData\022\"\n\004exit"
    "\030\002 \001(\0132\024.gvisor.syscall.Exit\022\r\n\005sysno\030\003 "
    "\001(\004\022\r\n\005flags\030\004 \001(\005\"\263\001\n\017InotifyAddWatch\0220"
    "\n\014context_data\030\001 \001(\0132\032.gvisor.common.Con"
    "textData\022\"\n\004exit\030\002 \001(\0132\024.gvisor.syscall."
    "Exit\022\r\n\005sysno\030\003 \001(\004\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_pa"
    "th\030\005 \001(\t\022\020\n\010pathname\030\006 \001(\t\022\014\n\004mask\030\007 \001(\r"
    "\"\236\001\n\016InotifyRmWatch\0220\n\014context_data\030\001 \001("
    "\0132\032.gvisor.common.ContextData\022\"\n\004exit\030\002 "
    "\001(\0132\024.gvisor.syscall.Exit\022\r\n\005sysno\030\003 \001(\004"
    "\022\n\n\002fd\030\004 \001(\005\022\017\n\007fd_path\030\005 \001(\t\022\n\n\002wd\030\006 \001("
    "\005\"\303\001\n\nSocketPair\0220\n\014context_data\030\001 \001(\0132\032"
    ".gvisor.common.ContextData\022\"\n\004exit\030\002 \001(\013"
    "2\024.gvisor.syscall.Exit\022\r\n\005sysno\030\003 \001(\004\022\016\n"
    "\006domain\030\004 \001(\005\022\014\n\004type\030\005 \001(\005\022\020\n\010protocol\030"
    "\006 \001(\005\022\017\n\007socket1\030\007 \001(\005\022\017\n\007socket2\030\010 \001(\005b"
    "\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto_deps[1] = {
        &::descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fcommon_2eproto,
};
static ::absl::once_flag descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto = {
    false,
    false,
    5287,
    descriptor_table_protodef_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
    "pkg/sentry/seccheck/points/syscall.proto",
    &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto_once,
    descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto_deps,
    1,
    33,
    schemas,
    file_default_instances,
    TableStruct_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto::offsets,
    file_level_enum_descriptors_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
    file_level_service_descriptors_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
};
namespace gvisor {
namespace syscall {
// ===================================================================

class Exit::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Exit>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Exit, _impl_._has_bits_);
};

Exit::Exit(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Exit_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Exit)
}
Exit::Exit(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Exit& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Exit_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE Exit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Exit::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, result_),
           0,
           offsetof(Impl_, errorno_) -
               offsetof(Impl_, result_) +
               sizeof(Impl_::errorno_));
}
Exit::~Exit() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Exit)
  SharedDtor(*this);
}
inline void Exit::SharedDtor(MessageLite& self) {
  Exit& this_ = static_cast<Exit&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Exit::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Exit(arena);
}
constexpr auto Exit::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Exit),
                                            alignof(Exit));
}
constexpr auto Exit::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Exit_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Exit::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Exit>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Exit::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Exit>(), &Exit::ByteSizeLong,
              &Exit::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Exit, _impl_._cached_size_),
          false,
      },
      &Exit::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Exit_class_data_ =
        Exit::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Exit::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Exit_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Exit_class_data_.tc_table);
  return Exit_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 0, 0, 2>
Exit::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Exit, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    Exit_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // int64 errorno = 2;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Exit, _impl_.errorno_), 1>(),
     {16, 1, 0,
      PROTOBUF_FIELD_OFFSET(Exit, _impl_.errorno_)}},
    // int64 result = 1;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Exit, _impl_.result_), 0>(),
     {8, 0, 0,
      PROTOBUF_FIELD_OFFSET(Exit, _impl_.result_)}},
  }}, {{
    65535, 65535
  }}, {{
    // int64 result = 1;
    {PROTOBUF_FIELD_OFFSET(Exit, _impl_.result_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // int64 errorno = 2;
    {PROTOBUF_FIELD_OFFSET(Exit, _impl_.errorno_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
  }},
  // no aux_entries
  {{
  }},
};
PROTOBUF_NOINLINE void Exit::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Exit)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    ::memset(&_impl_.result_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.errorno_) -
        reinterpret_cast<char*>(&_impl_.result_)) + sizeof(_impl_.errorno_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Exit::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Exit& this_ = static_cast<const Exit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Exit::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Exit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Exit)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // int64 result = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (this_._internal_result() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<1>(
              stream, this_._internal_result(), target);
    }
  }

  // int64 errorno = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_errorno() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<2>(
              stream, this_._internal_errorno(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Exit)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Exit::ByteSizeLong(const MessageLite& base) {
  const Exit& this_ = static_cast<const Exit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Exit::ByteSizeLong() const {
  const Exit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Exit)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // int64 result = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (this_._internal_result() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_result());
      }
    }
    // int64 errorno = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_errorno() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_errorno());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Exit::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Exit*>(&to_msg);
  auto& from = static_cast<const Exit&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Exit)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (from._internal_result() != 0) {
        _this->_impl_.result_ = from._impl_.result_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_errorno() != 0) {
        _this->_impl_.errorno_ = from._impl_.errorno_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Exit::CopyFrom(const Exit& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Exit)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Exit::InternalSwap(Exit* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Exit, _impl_.errorno_)
      + sizeof(Exit::_impl_.errorno_)
      - PROTOBUF_FIELD_OFFSET(Exit, _impl_.result_)>(
          reinterpret_cast<char*>(&_impl_.result_),
          reinterpret_cast<char*>(&other->_impl_.result_));
}

::google::protobuf::Metadata Exit::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Syscall::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Syscall>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Syscall, _impl_._has_bits_);
};

void Syscall::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Syscall::Syscall(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Syscall_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Syscall)
}
PROTOBUF_NDEBUG_INLINE Syscall::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Syscall& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Syscall::Syscall(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Syscall& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Syscall_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Syscall* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, arg6_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::arg6_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Syscall)
}
PROTOBUF_NDEBUG_INLINE Syscall::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Syscall::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, arg6_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::arg6_));
}
Syscall::~Syscall() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Syscall)
  SharedDtor(*this);
}
inline void Syscall::SharedDtor(MessageLite& self) {
  Syscall& this_ = static_cast<Syscall&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Syscall::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Syscall(arena);
}
constexpr auto Syscall::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Syscall),
                                            alignof(Syscall));
}
constexpr auto Syscall::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Syscall_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Syscall::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Syscall>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Syscall::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Syscall>(), &Syscall::ByteSizeLong,
              &Syscall::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Syscall, _impl_._cached_size_),
          false,
      },
      &Syscall::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Syscall_class_data_ =
        Syscall::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Syscall::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Syscall_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Syscall_class_data_.tc_table);
  return Syscall_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<4, 9, 2, 0, 2>
Syscall::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Syscall, _impl_._has_bits_),
    0, // no _extensions_
    10, 120,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294966276,  // skipmap
    offsetof(decltype(_table_), field_entries),
    9,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Syscall_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Syscall>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.exit_)}},
    {::_pbi::TcParser::MiniParse, {}},
    // uint64 sysno = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Syscall, _impl_.sysno_), 2>(),
     {32, 2, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.sysno_)}},
    // uint64 arg1 = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Syscall, _impl_.arg1_), 3>(),
     {40, 3, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg1_)}},
    // uint64 arg2 = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Syscall, _impl_.arg2_), 4>(),
     {48, 4, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg2_)}},
    // uint64 arg3 = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Syscall, _impl_.arg3_), 5>(),
     {56, 5, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg3_)}},
    // uint64 arg4 = 8;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Syscall, _impl_.arg4_), 6>(),
     {64, 6, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg4_)}},
    // uint64 arg5 = 9;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Syscall, _impl_.arg5_), 7>(),
     {72, 7, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg5_)}},
    // uint64 arg6 = 10;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Syscall, _impl_.arg6_), 8>(),
     {80, 8, 0,
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg6_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 4;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 arg1 = 5;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg1_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 arg2 = 6;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg2_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 arg3 = 7;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg3_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 arg4 = 8;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg4_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 arg5 = 9;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg5_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 arg6 = 10;
    {PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg6_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Syscall::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Syscall)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000fcU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.arg5_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.arg5_));
  }
  _impl_.arg6_ = ::uint64_t{0u};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Syscall::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Syscall& this_ = static_cast<const Syscall&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Syscall::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Syscall& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Syscall)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 4;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          4, this_._internal_sysno(), target);
    }
  }

  // uint64 arg1 = 5;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_arg1() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          5, this_._internal_arg1(), target);
    }
  }

  // uint64 arg2 = 6;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_arg2() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          6, this_._internal_arg2(), target);
    }
  }

  // uint64 arg3 = 7;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_arg3() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          7, this_._internal_arg3(), target);
    }
  }

  // uint64 arg4 = 8;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_arg4() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          8, this_._internal_arg4(), target);
    }
  }

  // uint64 arg5 = 9;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_arg5() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          9, this_._internal_arg5(), target);
    }
  }

  // uint64 arg6 = 10;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_arg6() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          10, this_._internal_arg6(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Syscall)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Syscall::ByteSizeLong(const MessageLite& base) {
  const Syscall& this_ = static_cast<const Syscall&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Syscall::ByteSizeLong() const {
  const Syscall& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Syscall)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 4;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // uint64 arg1 = 5;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_arg1() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_arg1());
      }
    }
    // uint64 arg2 = 6;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_arg2() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_arg2());
      }
    }
    // uint64 arg3 = 7;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_arg3() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_arg3());
      }
    }
    // uint64 arg4 = 8;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_arg4() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_arg4());
      }
    }
    // uint64 arg5 = 9;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_arg5() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_arg5());
      }
    }
  }
   {
    // uint64 arg6 = 10;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_arg6() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_arg6());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Syscall::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Syscall*>(&to_msg);
  auto& from = static_cast<const Syscall&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Syscall)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_arg1() != 0) {
        _this->_impl_.arg1_ = from._impl_.arg1_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_arg2() != 0) {
        _this->_impl_.arg2_ = from._impl_.arg2_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_arg3() != 0) {
        _this->_impl_.arg3_ = from._impl_.arg3_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_arg4() != 0) {
        _this->_impl_.arg4_ = from._impl_.arg4_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_arg5() != 0) {
        _this->_impl_.arg5_ = from._impl_.arg5_;
      }
    }
  }
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (from._internal_arg6() != 0) {
      _this->_impl_.arg6_ = from._impl_.arg6_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Syscall::CopyFrom(const Syscall& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Syscall)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Syscall::InternalSwap(Syscall* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Syscall, _impl_.arg6_)
      + sizeof(Syscall::_impl_.arg6_)
      - PROTOBUF_FIELD_OFFSET(Syscall, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Syscall::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Open::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Open>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Open, _impl_._has_bits_);
};

void Open::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
Open::Open(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Open_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Open)
}
PROTOBUF_NDEBUG_INLINE Open::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Open& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_),
        pathname_(arena, from.pathname_) {}

Open::Open(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Open& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Open_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Open* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, mode_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::mode_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Open)
}
PROTOBUF_NDEBUG_INLINE Open::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena),
        pathname_(arena) {}

inline void Open::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, mode_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::mode_));
}
Open::~Open() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Open)
  SharedDtor(*this);
}
inline void Open::SharedDtor(MessageLite& self) {
  Open& this_ = static_cast<Open&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  this_._impl_.pathname_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Open::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Open(arena);
}
constexpr auto Open::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Open),
                                            alignof(Open));
}
constexpr auto Open::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Open_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Open::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Open>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Open::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Open>(), &Open::ByteSizeLong,
              &Open::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Open, _impl_._cached_size_),
          false,
      },
      &Open::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Open_class_data_ =
        Open::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Open::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Open_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Open_class_data_.tc_table);
  return Open_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 8, 2, 51, 2>
Open::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Open, _impl_._has_bits_),
    0, // no _extensions_
    8, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967040,  // skipmap
    offsetof(decltype(_table_), field_entries),
    8,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Open_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Open>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // uint32 mode = 8;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Open, _impl_.mode_), 7>(),
     {64, 7, 0,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.mode_)}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 2, 0,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 3, 1,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Open, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.sysno_)}},
    // int64 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Open, _impl_.fd_), 5>(),
     {32, 5, 0,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.fd_path_)}},
    // string pathname = 6;
    {::_pbi::TcParser::FastUS1,
     {50, 1, 0,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.pathname_)}},
    // uint32 flags = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Open, _impl_.flags_), 6>(),
     {56, 6, 0,
      PROTOBUF_FIELD_OFFSET(Open, _impl_.flags_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.context_data_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.exit_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int64 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string pathname = 6;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.pathname_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // uint32 flags = 7;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.flags_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
    // uint32 mode = 8;
    {PROTOBUF_FIELD_OFFSET(Open, _impl_.mode_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\23\0\0\0\0\7\10\0\0\0\0\0\0\0\0\0"
    "gvisor.syscall.Open"
    "fd_path"
    "pathname"
  }},
};
PROTOBUF_NOINLINE void Open::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Open)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.pathname_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000f0U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.mode_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.mode_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Open::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Open& this_ = static_cast<const Open&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Open::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Open& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Open)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int64 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Open.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string pathname = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_pathname().empty()) {
      const ::std::string& _s = this_._internal_pathname();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Open.pathname");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // uint32 flags = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          7, this_._internal_flags(), target);
    }
  }

  // uint32 mode = 8;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_mode() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          8, this_._internal_mode(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Open)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Open::ByteSizeLong(const MessageLite& base) {
  const Open& this_ = static_cast<const Open&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Open::ByteSizeLong() const {
  const Open& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Open)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // string pathname = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_pathname().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_pathname());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_fd());
      }
    }
    // uint32 flags = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_flags());
      }
    }
    // uint32 mode = 8;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_mode() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_mode());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Open::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Open*>(&to_msg);
  auto& from = static_cast<const Open&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Open)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_pathname().empty()) {
        _this->_internal_set_pathname(from._internal_pathname());
      } else {
        if (_this->_impl_.pathname_.IsDefault()) {
          _this->_internal_set_pathname("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_mode() != 0) {
        _this->_impl_.mode_ = from._impl_.mode_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Open::CopyFrom(const Open& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Open)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Open::InternalSwap(Open* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.pathname_, &other->_impl_.pathname_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Open, _impl_.mode_)
      + sizeof(Open::_impl_.mode_)
      - PROTOBUF_FIELD_OFFSET(Open, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Open::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Close::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Close>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Close, _impl_._has_bits_);
};

void Close::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
Close::Close(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Close_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Close)
}
PROTOBUF_NDEBUG_INLINE Close::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Close& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

Close::Close(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Close& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Close_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Close* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, fd_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::fd_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Close)
}
PROTOBUF_NDEBUG_INLINE Close::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void Close::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, fd_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::fd_));
}
Close::~Close() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Close)
  SharedDtor(*this);
}
inline void Close::SharedDtor(MessageLite& self) {
  Close& this_ = static_cast<Close&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Close::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Close(arena);
}
constexpr auto Close::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Close),
                                            alignof(Close));
}
constexpr auto Close::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Close_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Close::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Close>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Close::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Close>(), &Close::ByteSizeLong,
              &Close::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Close, _impl_._cached_size_),
          false,
      },
      &Close::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Close_class_data_ =
        Close::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Close::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Close_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Close_class_data_.tc_table);
  return Close_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 5, 2, 36, 2>
Close::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Close, _impl_._has_bits_),
    0, // no _extensions_
    5, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967264,  // skipmap
    offsetof(decltype(_table_), field_entries),
    5,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Close_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Close>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(Close, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(Close, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Close, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(Close, _impl_.sysno_)}},
    // int64 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Close, _impl_.fd_), 4>(),
     {32, 4, 0,
      PROTOBUF_FIELD_OFFSET(Close, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Close, _impl_.fd_path_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Close, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Close, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Close, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int64 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Close, _impl_.fd_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Close, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\24\0\0\0\0\7\0\0"
    "gvisor.syscall.Close"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Close::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Close)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000018U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.fd_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.fd_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Close::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Close& this_ = static_cast<const Close&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Close::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Close& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Close)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int64 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Close.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Close)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Close::ByteSizeLong(const MessageLite& base) {
  const Close& this_ = static_cast<const Close&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Close::ByteSizeLong() const {
  const Close& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Close)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_fd());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Close::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Close*>(&to_msg);
  auto& from = static_cast<const Close&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Close)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Close::CopyFrom(const Close& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Close)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Close::InternalSwap(Close* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Close, _impl_.fd_)
      + sizeof(Close::_impl_.fd_)
      - PROTOBUF_FIELD_OFFSET(Close, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Close::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Read::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Read>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Read, _impl_._has_bits_);
};

void Read::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
Read::Read(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Read_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Read)
}
PROTOBUF_NDEBUG_INLINE Read::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Read& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

Read::Read(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Read& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Read_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Read* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Read)
}
PROTOBUF_NDEBUG_INLINE Read::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void Read::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
Read::~Read() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Read)
  SharedDtor(*this);
}
inline void Read::SharedDtor(MessageLite& self) {
  Read& this_ = static_cast<Read&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Read::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Read(arena);
}
constexpr auto Read::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Read),
                                            alignof(Read));
}
constexpr auto Read::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Read_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Read::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Read>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Read::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Read>(), &Read::ByteSizeLong,
              &Read::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Read, _impl_._cached_size_),
          false,
      },
      &Read::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Read_class_data_ =
        Read::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Read::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Read_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Read_class_data_.tc_table);
  return Read_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<4, 9, 2, 43, 2>
Read::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Read, _impl_._has_bits_),
    0, // no _extensions_
    9, 120,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294966784,  // skipmap
    offsetof(decltype(_table_), field_entries),
    9,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Read_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Read>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Read, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.sysno_)}},
    // int64 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Read, _impl_.fd_), 4>(),
     {32, 4, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.fd_path_)}},
    // uint64 count = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Read, _impl_.count_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.count_)}},
    // bool has_offset = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(Read, _impl_.has_offset_), 7>(),
     {56, 7, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.has_offset_)}},
    // int64 offset = 8;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Read, _impl_.offset_), 6>(),
     {64, 6, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.offset_)}},
    // uint32 flags = 9;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Read, _impl_.flags_), 8>(),
     {72, 8, 0,
      PROTOBUF_FIELD_OFFSET(Read, _impl_.flags_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int64 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.fd_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // uint64 count = 6;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.count_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // bool has_offset = 7;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.has_offset_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // int64 offset = 8;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.offset_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // uint32 flags = 9;
    {PROTOBUF_FIELD_OFFSET(Read, _impl_.flags_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\23\0\0\0\0\7\0\0\0\0\0\0\0\0\0\0"
    "gvisor.syscall.Read"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Read::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Read)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000f8U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.has_offset_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.has_offset_));
  }
  _impl_.flags_ = 0u;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Read::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Read& this_ = static_cast<const Read&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Read::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Read& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Read)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int64 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Read.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // uint64 count = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_count() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          6, this_._internal_count(), target);
    }
  }

  // bool has_offset = 7;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_has_offset() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          7, this_._internal_has_offset(), target);
    }
  }

  // int64 offset = 8;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_offset() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<8>(
              stream, this_._internal_offset(), target);
    }
  }

  // uint32 flags = 9;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          9, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Read)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Read::ByteSizeLong(const MessageLite& base) {
  const Read& this_ = static_cast<const Read&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Read::ByteSizeLong() const {
  const Read& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Read)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_fd());
      }
    }
    // uint64 count = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_count() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_count());
      }
    }
    // int64 offset = 8;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_offset() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_offset());
      }
    }
    // bool has_offset = 7;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_has_offset() != 0) {
        total_size += 2;
      }
    }
  }
   {
    // uint32 flags = 9;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Read::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Read*>(&to_msg);
  auto& from = static_cast<const Read&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Read)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_count() != 0) {
        _this->_impl_.count_ = from._impl_.count_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_offset() != 0) {
        _this->_impl_.offset_ = from._impl_.offset_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_has_offset() != 0) {
        _this->_impl_.has_offset_ = from._impl_.has_offset_;
      }
    }
  }
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (from._internal_flags() != 0) {
      _this->_impl_.flags_ = from._impl_.flags_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Read::CopyFrom(const Read& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Read)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Read::InternalSwap(Read* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Read, _impl_.flags_)
      + sizeof(Read::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(Read, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Read::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Write::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Write>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Write, _impl_._has_bits_);
};

void Write::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
Write::Write(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Write_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Write)
}
PROTOBUF_NDEBUG_INLINE Write::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Write& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

Write::Write(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Write& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Write_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Write* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Write)
}
PROTOBUF_NDEBUG_INLINE Write::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void Write::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
Write::~Write() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Write)
  SharedDtor(*this);
}
inline void Write::SharedDtor(MessageLite& self) {
  Write& this_ = static_cast<Write&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Write::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Write(arena);
}
constexpr auto Write::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Write),
                                            alignof(Write));
}
constexpr auto Write::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Write_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Write::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Write>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Write::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Write>(), &Write::ByteSizeLong,
              &Write::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Write, _impl_._cached_size_),
          false,
      },
      &Write::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Write_class_data_ =
        Write::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Write::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Write_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Write_class_data_.tc_table);
  return Write_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<4, 9, 2, 44, 2>
Write::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Write, _impl_._has_bits_),
    0, // no _extensions_
    9, 120,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294966784,  // skipmap
    offsetof(decltype(_table_), field_entries),
    9,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Write_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Write>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Write, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.sysno_)}},
    // int64 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Write, _impl_.fd_), 4>(),
     {32, 4, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.fd_path_)}},
    // uint64 count = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Write, _impl_.count_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.count_)}},
    // bool has_offset = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(Write, _impl_.has_offset_), 7>(),
     {56, 7, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.has_offset_)}},
    // int64 offset = 8;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Write, _impl_.offset_), 6>(),
     {64, 6, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.offset_)}},
    // uint32 flags = 9;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Write, _impl_.flags_), 8>(),
     {72, 8, 0,
      PROTOBUF_FIELD_OFFSET(Write, _impl_.flags_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int64 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.fd_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // uint64 count = 6;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.count_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // bool has_offset = 7;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.has_offset_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // int64 offset = 8;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.offset_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // uint32 flags = 9;
    {PROTOBUF_FIELD_OFFSET(Write, _impl_.flags_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\24\0\0\0\0\7\0\0\0\0\0\0\0\0\0\0"
    "gvisor.syscall.Write"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Write::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Write)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000f8U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.has_offset_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.has_offset_));
  }
  _impl_.flags_ = 0u;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Write::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Write& this_ = static_cast<const Write&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Write::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Write& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Write)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int64 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Write.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // uint64 count = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_count() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          6, this_._internal_count(), target);
    }
  }

  // bool has_offset = 7;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_has_offset() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          7, this_._internal_has_offset(), target);
    }
  }

  // int64 offset = 8;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_offset() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<8>(
              stream, this_._internal_offset(), target);
    }
  }

  // uint32 flags = 9;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          9, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Write)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Write::ByteSizeLong(const MessageLite& base) {
  const Write& this_ = static_cast<const Write&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Write::ByteSizeLong() const {
  const Write& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Write)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_fd());
      }
    }
    // uint64 count = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_count() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_count());
      }
    }
    // int64 offset = 8;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_offset() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_offset());
      }
    }
    // bool has_offset = 7;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_has_offset() != 0) {
        total_size += 2;
      }
    }
  }
   {
    // uint32 flags = 9;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Write::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Write*>(&to_msg);
  auto& from = static_cast<const Write&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Write)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_count() != 0) {
        _this->_impl_.count_ = from._impl_.count_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_offset() != 0) {
        _this->_impl_.offset_ = from._impl_.offset_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_has_offset() != 0) {
        _this->_impl_.has_offset_ = from._impl_.has_offset_;
      }
    }
  }
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (from._internal_flags() != 0) {
      _this->_impl_.flags_ = from._impl_.flags_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Write::CopyFrom(const Write& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Write)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Write::InternalSwap(Write* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Write, _impl_.flags_)
      + sizeof(Write::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(Write, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Write::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Connect::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Connect>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Connect, _impl_._has_bits_);
};

void Connect::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
Connect::Connect(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Connect_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Connect)
}
PROTOBUF_NDEBUG_INLINE Connect::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Connect& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_),
        address_(arena, from.address_) {}

Connect::Connect(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Connect& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Connect_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Connect* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, fd_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::fd_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Connect)
}
PROTOBUF_NDEBUG_INLINE Connect::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena),
        address_(arena) {}

inline void Connect::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, fd_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::fd_));
}
Connect::~Connect() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Connect)
  SharedDtor(*this);
}
inline void Connect::SharedDtor(MessageLite& self) {
  Connect& this_ = static_cast<Connect&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  this_._impl_.address_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Connect::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Connect(arena);
}
constexpr auto Connect::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Connect),
                                            alignof(Connect));
}
constexpr auto Connect::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Connect_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Connect::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Connect>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Connect::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Connect>(), &Connect::ByteSizeLong,
              &Connect::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Connect, _impl_._cached_size_),
          false,
      },
      &Connect::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Connect_class_data_ =
        Connect::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Connect::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Connect_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Connect_class_data_.tc_table);
  return Connect_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 2, 38, 2>
Connect::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Connect, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Connect_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Connect>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 2, 0,
      PROTOBUF_FIELD_OFFSET(Connect, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 3, 1,
      PROTOBUF_FIELD_OFFSET(Connect, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Connect, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(Connect, _impl_.sysno_)}},
    // int64 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Connect, _impl_.fd_), 5>(),
     {32, 5, 0,
      PROTOBUF_FIELD_OFFSET(Connect, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Connect, _impl_.fd_path_)}},
    // bytes address = 6;
    {::_pbi::TcParser::FastBS1,
     {50, 1, 0,
      PROTOBUF_FIELD_OFFSET(Connect, _impl_.address_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Connect, _impl_.context_data_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Connect, _impl_.exit_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Connect, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int64 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Connect, _impl_.fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Connect, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // bytes address = 6;
    {PROTOBUF_FIELD_OFFSET(Connect, _impl_.address_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\26\0\0\0\0\7\0\0"
    "gvisor.syscall.Connect"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Connect::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Connect)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.address_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000030U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.fd_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.fd_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Connect::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Connect& this_ = static_cast<const Connect&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Connect::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Connect& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Connect)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int64 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Connect.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // bytes address = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_address().empty()) {
      const ::std::string& _s = this_._internal_address();
      target = stream->WriteBytesMaybeAliased(6, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Connect)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Connect::ByteSizeLong(const MessageLite& base) {
  const Connect& this_ = static_cast<const Connect&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Connect::ByteSizeLong() const {
  const Connect& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Connect)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // bytes address = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_address().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::BytesSize(
                                        this_._internal_address());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_fd());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Connect::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Connect*>(&to_msg);
  auto& from = static_cast<const Connect&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Connect)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_address().empty()) {
        _this->_internal_set_address(from._internal_address());
      } else {
        if (_this->_impl_.address_.IsDefault()) {
          _this->_internal_set_address("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Connect::CopyFrom(const Connect& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Connect)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Connect::InternalSwap(Connect* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.address_, &other->_impl_.address_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Connect, _impl_.fd_)
      + sizeof(Connect::_impl_.fd_)
      - PROTOBUF_FIELD_OFFSET(Connect, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Connect::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Execve::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Execve>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Execve, _impl_._has_bits_);
};

void Execve::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000010U);
}
Execve::Execve(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Execve_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Execve)
}
PROTOBUF_NDEBUG_INLINE Execve::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Execve& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        argv_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::gvisor::syscall::Execve,
            PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.argv_)>()
        , from.argv_}
        #else
        argv_ { visibility, arena, from.argv_ }
        #endif
        ,
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        envv_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::gvisor::syscall::Execve,
            PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.envv_)>()
        , from.envv_}
        #else
        envv_ { visibility, arena, from.envv_ }
        #endif
        ,
        fd_path_(arena, from.fd_path_),
        pathname_(arena, from.pathname_) {}

Execve::Execve(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Execve& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Execve_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Execve* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000020U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Execve)
}
PROTOBUF_NDEBUG_INLINE Execve::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        argv_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::gvisor::syscall::Execve,
            PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.argv_)>()
        }
        #else
        argv_ { visibility, arena }
        #endif
        ,
        #ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
        envv_{visibility, ::_pbi::InternalMetadataOffset::Build<
            ::gvisor::syscall::Execve,
            PROTOBUF_FIELD_OFFSET(::gvisor::syscall::Execve, _impl_.envv_)>()
        }
        #else
        envv_ { visibility, arena }
        #endif
        ,
        fd_path_(arena),
        pathname_(arena) {}

inline void Execve::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
Execve::~Execve() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Execve)
  SharedDtor(*this);
}
inline void Execve::SharedDtor(MessageLite& self) {
  Execve& this_ = static_cast<Execve&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  this_._impl_.pathname_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Execve::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Execve(arena);
}
#ifdef PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto Execve::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Execve),
                                            alignof(Execve));
}
#else  // !PROTOBUF_INTERNAL_REMOVE_ARENA_PTRS_REPEATED_PTR_FIELD
constexpr auto Execve::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.argv_) +
          decltype(Execve::_impl_.argv_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.envv_) +
          decltype(Execve::_impl_.envv_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::CopyInit(
        sizeof(Execve), alignof(Execve), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&Execve::PlacementNew_,
                                 sizeof(Execve),
                                 alignof(Execve));
  }
}
#endif
constexpr auto Execve::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Execve_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Execve::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Execve>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Execve::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Execve>(), &Execve::ByteSizeLong,
              &Execve::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Execve, _impl_._cached_size_),
          false,
      },
      &Execve::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Execve_class_data_ =
        Execve::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Execve::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Execve_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Execve_class_data_.tc_table);
  return Execve_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<4, 9, 2, 61, 2>
Execve::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Execve, _impl_._has_bits_),
    0, // no _extensions_
    9, 120,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294966784,  // skipmap
    offsetof(decltype(_table_), field_entries),
    9,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Execve_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Execve>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 4, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 5, 1,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Execve, _impl_.sysno_), 6>(),
     {24, 6, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.sysno_)}},
    // int64 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Execve, _impl_.fd_), 7>(),
     {32, 7, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 2, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.fd_path_)}},
    // string pathname = 6;
    {::_pbi::TcParser::FastUS1,
     {50, 3, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.pathname_)}},
    // repeated string argv = 7;
    {::_pbi::TcParser::FastUR1,
     {58, 0, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.argv_)}},
    // repeated string envv = 8;
    {::_pbi::TcParser::FastUR1,
     {66, 1, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.envv_)}},
    // uint32 flags = 9;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Execve, _impl_.flags_), 8>(),
     {72, 8, 0,
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.flags_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.context_data_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.exit_), _Internal::kHasBitsOffset + 5, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.sysno_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int64 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.fd_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.fd_path_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string pathname = 6;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.pathname_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // repeated string argv = 7;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.argv_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kUtf8String | ::_fl::kRepSString)},
    // repeated string envv = 8;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.envv_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kUtf8String | ::_fl::kRepSString)},
    // uint32 flags = 9;
    {PROTOBUF_FIELD_OFFSET(Execve, _impl_.flags_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\25\0\0\0\0\7\10\4\4\0\0\0\0\0\0\0"
    "gvisor.syscall.Execve"
    "fd_path"
    "pathname"
    "argv"
    "envv"
  }},
};
PROTOBUF_NOINLINE void Execve::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Execve)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      _impl_.argv_.Clear();
    }
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000002U)) {
      _impl_.envv_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.pathname_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000c0U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.fd_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.fd_));
  }
  _impl_.flags_ = 0u;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Execve::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Execve& this_ = static_cast<const Execve&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Execve::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Execve& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Execve)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int64 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Execve.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string pathname = 6;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_pathname().empty()) {
      const ::std::string& _s = this_._internal_pathname();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Execve.pathname");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // repeated string argv = 7;
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
    for (int i = 0, n = this_._internal_argv_size(); i < n; ++i) {
      const auto& s = this_._internal_argv().Get(i);
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          s.data(), static_cast<int>(s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Execve.argv");
      target = stream->WriteString(7, s, target);
    }
  }

  // repeated string envv = 8;
  if (CheckHasBitForRepeated(cached_has_bits, 0x00000002U)) {
    for (int i = 0, n = this_._internal_envv_size(); i < n; ++i) {
      const auto& s = this_._internal_envv().Get(i);
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          s.data(), static_cast<int>(s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Execve.envv");
      target = stream->WriteString(8, s, target);
    }
  }

  // uint32 flags = 9;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          9, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Execve)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Execve::ByteSizeLong(const MessageLite& base) {
  const Execve& this_ = static_cast<const Execve&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Execve::ByteSizeLong() const {
  const Execve& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Execve)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // repeated string argv = 7;
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_argv().size());
      for (int i = 0, n = this_._internal_argv().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
            this_._internal_argv().Get(i));
      }
    }
    // repeated string envv = 8;
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000002U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_envv().size());
      for (int i = 0, n = this_._internal_envv().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
            this_._internal_envv().Get(i));
      }
    }
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // string pathname = 6;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_pathname().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_pathname());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_fd());
      }
    }
  }
   {
    // uint32 flags = 9;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Execve::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Execve*>(&to_msg);
  auto& from = static_cast<const Execve&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Execve)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_argv()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_argv());
    }
    if (CheckHasBitForRepeated(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_envv()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_envv());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_pathname().empty()) {
        _this->_internal_set_pathname(from._internal_pathname());
      } else {
        if (_this->_impl_.pathname_.IsDefault()) {
          _this->_internal_set_pathname("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
  }
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (from._internal_flags() != 0) {
      _this->_impl_.flags_ = from._impl_.flags_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Execve::CopyFrom(const Execve& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Execve)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Execve::InternalSwap(Execve* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.argv_.InternalSwap(&other->_impl_.argv_);
  _impl_.envv_.InternalSwap(&other->_impl_.envv_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.pathname_, &other->_impl_.pathname_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Execve, _impl_.flags_)
      + sizeof(Execve::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(Execve, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Execve::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Socket::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Socket>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Socket, _impl_._has_bits_);
};

void Socket::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Socket::Socket(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Socket_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Socket)
}
PROTOBUF_NDEBUG_INLINE Socket::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Socket& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Socket::Socket(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Socket& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Socket_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Socket* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, protocol_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::protocol_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Socket)
}
PROTOBUF_NDEBUG_INLINE Socket::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Socket::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, protocol_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::protocol_));
}
Socket::~Socket() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Socket)
  SharedDtor(*this);
}
inline void Socket::SharedDtor(MessageLite& self) {
  Socket& this_ = static_cast<Socket&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Socket::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Socket(arena);
}
constexpr auto Socket::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Socket),
                                            alignof(Socket));
}
constexpr auto Socket::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Socket_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Socket::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Socket>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Socket::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Socket>(), &Socket::ByteSizeLong,
              &Socket::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Socket, _impl_._cached_size_),
          false,
      },
      &Socket::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Socket_class_data_ =
        Socket::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Socket::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Socket_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Socket_class_data_.tc_table);
  return Socket_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 2, 0, 2>
Socket::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Socket, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Socket_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Socket>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Socket, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Socket, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Socket, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(Socket, _impl_.sysno_)}},
    // int32 domain = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Socket, _impl_.domain_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(Socket, _impl_.domain_)}},
    // int32 type = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Socket, _impl_.type_), 4>(),
     {40, 4, 0,
      PROTOBUF_FIELD_OFFSET(Socket, _impl_.type_)}},
    // int32 protocol = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Socket, _impl_.protocol_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(Socket, _impl_.protocol_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Socket, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Socket, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Socket, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 domain = 4;
    {PROTOBUF_FIELD_OFFSET(Socket, _impl_.domain_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 type = 5;
    {PROTOBUF_FIELD_OFFSET(Socket, _impl_.type_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 protocol = 6;
    {PROTOBUF_FIELD_OFFSET(Socket, _impl_.protocol_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Socket::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Socket)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000003cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.protocol_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.protocol_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Socket::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Socket& this_ = static_cast<const Socket&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Socket::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Socket& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Socket)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 domain = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_domain() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_domain(), target);
    }
  }

  // int32 type = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_type() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<5>(
              stream, this_._internal_type(), target);
    }
  }

  // int32 protocol = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_protocol() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<6>(
              stream, this_._internal_protocol(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Socket)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Socket::ByteSizeLong(const MessageLite& base) {
  const Socket& this_ = static_cast<const Socket&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Socket::ByteSizeLong() const {
  const Socket& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Socket)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 domain = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_domain() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_domain());
      }
    }
    // int32 type = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_type() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_type());
      }
    }
    // int32 protocol = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_protocol() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_protocol());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Socket::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Socket*>(&to_msg);
  auto& from = static_cast<const Socket&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Socket)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_domain() != 0) {
        _this->_impl_.domain_ = from._impl_.domain_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_type() != 0) {
        _this->_impl_.type_ = from._impl_.type_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_protocol() != 0) {
        _this->_impl_.protocol_ = from._impl_.protocol_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Socket::CopyFrom(const Socket& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Socket)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Socket::InternalSwap(Socket* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Socket, _impl_.protocol_)
      + sizeof(Socket::_impl_.protocol_)
      - PROTOBUF_FIELD_OFFSET(Socket, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Socket::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Chdir::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Chdir>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Chdir, _impl_._has_bits_);
};

void Chdir::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
Chdir::Chdir(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Chdir_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Chdir)
}
PROTOBUF_NDEBUG_INLINE Chdir::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Chdir& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_),
        pathname_(arena, from.pathname_) {}

Chdir::Chdir(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Chdir& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Chdir_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Chdir* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, fd_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::fd_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Chdir)
}
PROTOBUF_NDEBUG_INLINE Chdir::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena),
        pathname_(arena) {}

inline void Chdir::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, fd_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::fd_));
}
Chdir::~Chdir() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Chdir)
  SharedDtor(*this);
}
inline void Chdir::SharedDtor(MessageLite& self) {
  Chdir& this_ = static_cast<Chdir&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  this_._impl_.pathname_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Chdir::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Chdir(arena);
}
constexpr auto Chdir::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Chdir),
                                            alignof(Chdir));
}
constexpr auto Chdir::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Chdir_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Chdir::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Chdir>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Chdir::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Chdir>(), &Chdir::ByteSizeLong,
              &Chdir::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Chdir, _impl_._cached_size_),
          false,
      },
      &Chdir::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Chdir_class_data_ =
        Chdir::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Chdir::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Chdir_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Chdir_class_data_.tc_table);
  return Chdir_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 2, 44, 2>
Chdir::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Chdir, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Chdir_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Chdir>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 2, 0,
      PROTOBUF_FIELD_OFFSET(Chdir, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 3, 1,
      PROTOBUF_FIELD_OFFSET(Chdir, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Chdir, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(Chdir, _impl_.sysno_)}},
    // int64 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Chdir, _impl_.fd_), 5>(),
     {32, 5, 0,
      PROTOBUF_FIELD_OFFSET(Chdir, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Chdir, _impl_.fd_path_)}},
    // string pathname = 6;
    {::_pbi::TcParser::FastUS1,
     {50, 1, 0,
      PROTOBUF_FIELD_OFFSET(Chdir, _impl_.pathname_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Chdir, _impl_.context_data_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Chdir, _impl_.exit_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Chdir, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int64 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Chdir, _impl_.fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Chdir, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string pathname = 6;
    {PROTOBUF_FIELD_OFFSET(Chdir, _impl_.pathname_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\24\0\0\0\0\7\10\0"
    "gvisor.syscall.Chdir"
    "fd_path"
    "pathname"
  }},
};
PROTOBUF_NOINLINE void Chdir::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Chdir)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.pathname_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000030U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.fd_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.fd_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Chdir::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Chdir& this_ = static_cast<const Chdir&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Chdir::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Chdir& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Chdir)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int64 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Chdir.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string pathname = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_pathname().empty()) {
      const ::std::string& _s = this_._internal_pathname();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Chdir.pathname");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Chdir)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Chdir::ByteSizeLong(const MessageLite& base) {
  const Chdir& this_ = static_cast<const Chdir&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Chdir::ByteSizeLong() const {
  const Chdir& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Chdir)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // string pathname = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_pathname().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_pathname());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_fd());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Chdir::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Chdir*>(&to_msg);
  auto& from = static_cast<const Chdir&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Chdir)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_pathname().empty()) {
        _this->_internal_set_pathname(from._internal_pathname());
      } else {
        if (_this->_impl_.pathname_.IsDefault()) {
          _this->_internal_set_pathname("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Chdir::CopyFrom(const Chdir& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Chdir)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Chdir::InternalSwap(Chdir* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.pathname_, &other->_impl_.pathname_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Chdir, _impl_.fd_)
      + sizeof(Chdir::_impl_.fd_)
      - PROTOBUF_FIELD_OFFSET(Chdir, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Chdir::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Setresid::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Setresid>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Setresid, _impl_._has_bits_);
};

void Setresid::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Setresid::Setresid(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Setresid_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Setresid)
}
PROTOBUF_NDEBUG_INLINE Setresid::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Setresid& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Setresid::Setresid(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Setresid& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Setresid_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Setresid* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, sid_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::sid_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Setresid)
}
PROTOBUF_NDEBUG_INLINE Setresid::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Setresid::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, sid_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::sid_));
}
Setresid::~Setresid() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Setresid)
  SharedDtor(*this);
}
inline void Setresid::SharedDtor(MessageLite& self) {
  Setresid& this_ = static_cast<Setresid&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Setresid::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Setresid(arena);
}
constexpr auto Setresid::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Setresid),
                                            alignof(Setresid));
}
constexpr auto Setresid::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Setresid_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Setresid::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Setresid>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Setresid::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Setresid>(), &Setresid::ByteSizeLong,
              &Setresid::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Setresid, _impl_._cached_size_),
          false,
      },
      &Setresid::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Setresid_class_data_ =
        Setresid::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Setresid::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Setresid_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Setresid_class_data_.tc_table);
  return Setresid_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 2, 0, 2>
Setresid::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Setresid, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Setresid_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Setresid>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Setresid, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Setresid, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Setresid, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(Setresid, _impl_.sysno_)}},
    // uint32 rid = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Setresid, _impl_.rid_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(Setresid, _impl_.rid_)}},
    // uint32 eid = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Setresid, _impl_.eid_), 4>(),
     {40, 4, 0,
      PROTOBUF_FIELD_OFFSET(Setresid, _impl_.eid_)}},
    // uint32 sid = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Setresid, _impl_.sid_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(Setresid, _impl_.sid_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Setresid, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Setresid, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Setresid, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint32 rid = 4;
    {PROTOBUF_FIELD_OFFSET(Setresid, _impl_.rid_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
    // uint32 eid = 5;
    {PROTOBUF_FIELD_OFFSET(Setresid, _impl_.eid_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
    // uint32 sid = 6;
    {PROTOBUF_FIELD_OFFSET(Setresid, _impl_.sid_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Setresid::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Setresid)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000003cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.sid_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.sid_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Setresid::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Setresid& this_ = static_cast<const Setresid&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Setresid::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Setresid& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Setresid)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // uint32 rid = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_rid() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          4, this_._internal_rid(), target);
    }
  }

  // uint32 eid = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_eid() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          5, this_._internal_eid(), target);
    }
  }

  // uint32 sid = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_sid() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          6, this_._internal_sid(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Setresid)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Setresid::ByteSizeLong(const MessageLite& base) {
  const Setresid& this_ = static_cast<const Setresid&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Setresid::ByteSizeLong() const {
  const Setresid& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Setresid)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // uint32 rid = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_rid() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_rid());
      }
    }
    // uint32 eid = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_eid() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_eid());
      }
    }
    // uint32 sid = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_sid() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_sid());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Setresid::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Setresid*>(&to_msg);
  auto& from = static_cast<const Setresid&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Setresid)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_rid() != 0) {
        _this->_impl_.rid_ = from._impl_.rid_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_eid() != 0) {
        _this->_impl_.eid_ = from._impl_.eid_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_sid() != 0) {
        _this->_impl_.sid_ = from._impl_.sid_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Setresid::CopyFrom(const Setresid& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Setresid)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Setresid::InternalSwap(Setresid* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Setresid, _impl_.sid_)
      + sizeof(Setresid::_impl_.sid_)
      - PROTOBUF_FIELD_OFFSET(Setresid, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Setresid::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Setid::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Setid>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Setid, _impl_._has_bits_);
};

void Setid::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Setid::Setid(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Setid_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Setid)
}
PROTOBUF_NDEBUG_INLINE Setid::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Setid& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Setid::Setid(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Setid& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Setid_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Setid* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, id_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::id_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Setid)
}
PROTOBUF_NDEBUG_INLINE Setid::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Setid::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, id_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::id_));
}
Setid::~Setid() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Setid)
  SharedDtor(*this);
}
inline void Setid::SharedDtor(MessageLite& self) {
  Setid& this_ = static_cast<Setid&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Setid::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Setid(arena);
}
constexpr auto Setid::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Setid),
                                            alignof(Setid));
}
constexpr auto Setid::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Setid_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Setid::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Setid>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Setid::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Setid>(), &Setid::ByteSizeLong,
              &Setid::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Setid, _impl_._cached_size_),
          false,
      },
      &Setid::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Setid_class_data_ =
        Setid::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Setid::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Setid_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Setid_class_data_.tc_table);
  return Setid_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<2, 4, 2, 0, 2>
Setid::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Setid, _impl_._has_bits_),
    0, // no _extensions_
    4, 24,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967280,  // skipmap
    offsetof(decltype(_table_), field_entries),
    4,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Setid_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Setid>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // uint32 id = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Setid, _impl_.id_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(Setid, _impl_.id_)}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Setid, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Setid, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Setid, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(Setid, _impl_.sysno_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Setid, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Setid, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Setid, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint32 id = 4;
    {PROTOBUF_FIELD_OFFSET(Setid, _impl_.id_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Setid::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Setid)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000000cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.id_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.id_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Setid::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Setid& this_ = static_cast<const Setid&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Setid::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Setid& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Setid)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // uint32 id = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          4, this_._internal_id(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Setid)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Setid::ByteSizeLong(const MessageLite& base) {
  const Setid& this_ = static_cast<const Setid&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Setid::ByteSizeLong() const {
  const Setid& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Setid)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // uint32 id = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_id());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Setid::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Setid*>(&to_msg);
  auto& from = static_cast<const Setid&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Setid)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_id() != 0) {
        _this->_impl_.id_ = from._impl_.id_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Setid::CopyFrom(const Setid& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Setid)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Setid::InternalSwap(Setid* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Setid, _impl_.id_)
      + sizeof(Setid::_impl_.id_)
      - PROTOBUF_FIELD_OFFSET(Setid, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Setid::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class StructRlimit::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<StructRlimit>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_._has_bits_);
};

StructRlimit::StructRlimit(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, StructRlimit_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.StructRlimit)
}
StructRlimit::StructRlimit(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const StructRlimit& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, StructRlimit_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE StructRlimit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void StructRlimit::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, cur_),
           0,
           offsetof(Impl_, max_) -
               offsetof(Impl_, cur_) +
               sizeof(Impl_::max_));
}
StructRlimit::~StructRlimit() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.StructRlimit)
  SharedDtor(*this);
}
inline void StructRlimit::SharedDtor(MessageLite& self) {
  StructRlimit& this_ = static_cast<StructRlimit&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL StructRlimit::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) StructRlimit(arena);
}
constexpr auto StructRlimit::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(StructRlimit),
                                            alignof(StructRlimit));
}
constexpr auto StructRlimit::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_StructRlimit_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &StructRlimit::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<StructRlimit>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &StructRlimit::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<StructRlimit>(), &StructRlimit::ByteSizeLong,
              &StructRlimit::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_._cached_size_),
          false,
      },
      &StructRlimit::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull StructRlimit_class_data_ =
        StructRlimit::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
StructRlimit::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&StructRlimit_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(StructRlimit_class_data_.tc_table);
  return StructRlimit_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 0, 0, 2>
StructRlimit::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    StructRlimit_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::StructRlimit>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // uint64 max = 2;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(StructRlimit, _impl_.max_), 1>(),
     {16, 1, 0,
      PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_.max_)}},
    // uint64 cur = 1;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(StructRlimit, _impl_.cur_), 0>(),
     {8, 0, 0,
      PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_.cur_)}},
  }}, {{
    65535, 65535
  }}, {{
    // uint64 cur = 1;
    {PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_.cur_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 max = 2;
    {PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_.max_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
  }},
  // no aux_entries
  {{
  }},
};
PROTOBUF_NOINLINE void StructRlimit::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.StructRlimit)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    ::memset(&_impl_.cur_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.max_) -
        reinterpret_cast<char*>(&_impl_.cur_)) + sizeof(_impl_.max_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL StructRlimit::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const StructRlimit& this_ = static_cast<const StructRlimit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL StructRlimit::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const StructRlimit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.StructRlimit)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // uint64 cur = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (this_._internal_cur() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          1, this_._internal_cur(), target);
    }
  }

  // uint64 max = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_max() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          2, this_._internal_max(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.StructRlimit)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t StructRlimit::ByteSizeLong(const MessageLite& base) {
  const StructRlimit& this_ = static_cast<const StructRlimit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t StructRlimit::ByteSizeLong() const {
  const StructRlimit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.StructRlimit)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // uint64 cur = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (this_._internal_cur() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_cur());
      }
    }
    // uint64 max = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_max() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_max());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void StructRlimit::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<StructRlimit*>(&to_msg);
  auto& from = static_cast<const StructRlimit&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.StructRlimit)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (from._internal_cur() != 0) {
        _this->_impl_.cur_ = from._impl_.cur_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_max() != 0) {
        _this->_impl_.max_ = from._impl_.max_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void StructRlimit::CopyFrom(const StructRlimit& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.StructRlimit)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void StructRlimit::InternalSwap(StructRlimit* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_.max_)
      + sizeof(StructRlimit::_impl_.max_)
      - PROTOBUF_FIELD_OFFSET(StructRlimit, _impl_.cur_)>(
          reinterpret_cast<char*>(&_impl_.cur_),
          reinterpret_cast<char*>(&other->_impl_.cur_));
}

::google::protobuf::Metadata StructRlimit::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Prlimit::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Prlimit>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Prlimit, _impl_._has_bits_);
};

void Prlimit::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Prlimit::Prlimit(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Prlimit_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Prlimit)
}
PROTOBUF_NDEBUG_INLINE Prlimit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Prlimit& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Prlimit::Prlimit(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Prlimit& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Prlimit_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Prlimit* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  _impl_.new_limit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.new_limit_)
                : nullptr;
  _impl_.old_limit_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.old_limit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, pid_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::pid_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Prlimit)
}
PROTOBUF_NDEBUG_INLINE Prlimit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Prlimit::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, pid_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::pid_));
}
Prlimit::~Prlimit() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Prlimit)
  SharedDtor(*this);
}
inline void Prlimit::SharedDtor(MessageLite& self) {
  Prlimit& this_ = static_cast<Prlimit&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  delete this_._impl_.new_limit_;
  delete this_._impl_.old_limit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Prlimit::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Prlimit(arena);
}
constexpr auto Prlimit::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Prlimit),
                                            alignof(Prlimit));
}
constexpr auto Prlimit::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Prlimit_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Prlimit::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Prlimit>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Prlimit::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Prlimit>(), &Prlimit::ByteSizeLong,
              &Prlimit::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Prlimit, _impl_._cached_size_),
          false,
      },
      &Prlimit::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Prlimit_class_data_ =
        Prlimit::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Prlimit::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Prlimit_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Prlimit_class_data_.tc_table);
  return Prlimit_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 4, 0, 2>
Prlimit::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Prlimit, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    4,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Prlimit_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Prlimit>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Prlimit, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.sysno_)}},
    // int32 pid = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Prlimit, _impl_.pid_), 6>(),
     {32, 6, 0,
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.pid_)}},
    // int64 resource = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Prlimit, _impl_.resource_), 5>(),
     {40, 5, 0,
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.resource_)}},
    // .gvisor.syscall.StructRlimit new_limit = 6;
    {::_pbi::TcParser::FastMtS1,
     {50, 2, 2,
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.new_limit_)}},
    // .gvisor.syscall.StructRlimit old_limit = 7;
    {::_pbi::TcParser::FastMtS1,
     {58, 3, 3,
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.old_limit_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 pid = 4;
    {PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.pid_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int64 resource = 5;
    {PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.resource_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // .gvisor.syscall.StructRlimit new_limit = 6;
    {PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.new_limit_), _Internal::kHasBitsOffset + 2, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.StructRlimit old_limit = 7;
    {PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.old_limit_), _Internal::kHasBitsOffset + 3, 3, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::StructRlimit>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::StructRlimit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Prlimit::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Prlimit)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.new_limit_ != nullptr);
      _impl_.new_limit_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.old_limit_ != nullptr);
      _impl_.old_limit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000070U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.pid_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.pid_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Prlimit::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Prlimit& this_ = static_cast<const Prlimit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Prlimit::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Prlimit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Prlimit)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 pid = 4;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_pid() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_pid(), target);
    }
  }

  // int64 resource = 5;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_resource() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<5>(
              stream, this_._internal_resource(), target);
    }
  }

  // .gvisor.syscall.StructRlimit new_limit = 6;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        6, *this_._impl_.new_limit_, this_._impl_.new_limit_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.StructRlimit old_limit = 7;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        7, *this_._impl_.old_limit_, this_._impl_.old_limit_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Prlimit)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Prlimit::ByteSizeLong(const MessageLite& base) {
  const Prlimit& this_ = static_cast<const Prlimit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Prlimit::ByteSizeLong() const {
  const Prlimit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Prlimit)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // .gvisor.syscall.StructRlimit new_limit = 6;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.new_limit_);
    }
    // .gvisor.syscall.StructRlimit old_limit = 7;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.old_limit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int64 resource = 5;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_resource() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_resource());
      }
    }
    // int32 pid = 4;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_pid() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_pid());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Prlimit::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Prlimit*>(&to_msg);
  auto& from = static_cast<const Prlimit&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Prlimit)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.new_limit_ != nullptr);
      if (_this->_impl_.new_limit_ == nullptr) {
        _this->_impl_.new_limit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.new_limit_);
      } else {
        _this->_impl_.new_limit_->MergeFrom(*from._impl_.new_limit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.old_limit_ != nullptr);
      if (_this->_impl_.old_limit_ == nullptr) {
        _this->_impl_.old_limit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.old_limit_);
      } else {
        _this->_impl_.old_limit_->MergeFrom(*from._impl_.old_limit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_resource() != 0) {
        _this->_impl_.resource_ = from._impl_.resource_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_pid() != 0) {
        _this->_impl_.pid_ = from._impl_.pid_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Prlimit::CopyFrom(const Prlimit& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Prlimit)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Prlimit::InternalSwap(Prlimit* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.pid_)
      + sizeof(Prlimit::_impl_.pid_)
      - PROTOBUF_FIELD_OFFSET(Prlimit, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Prlimit::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Pipe::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Pipe>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Pipe, _impl_._has_bits_);
};

void Pipe::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Pipe::Pipe(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Pipe_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Pipe)
}
PROTOBUF_NDEBUG_INLINE Pipe::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Pipe& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Pipe::Pipe(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Pipe& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Pipe_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Pipe* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, writer_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::writer_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Pipe)
}
PROTOBUF_NDEBUG_INLINE Pipe::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Pipe::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, writer_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::writer_));
}
Pipe::~Pipe() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Pipe)
  SharedDtor(*this);
}
inline void Pipe::SharedDtor(MessageLite& self) {
  Pipe& this_ = static_cast<Pipe&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Pipe::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Pipe(arena);
}
constexpr auto Pipe::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Pipe),
                                            alignof(Pipe));
}
constexpr auto Pipe::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Pipe_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Pipe::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Pipe>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Pipe::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Pipe>(), &Pipe::ByteSizeLong,
              &Pipe::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Pipe, _impl_._cached_size_),
          false,
      },
      &Pipe::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Pipe_class_data_ =
        Pipe::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Pipe::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Pipe_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Pipe_class_data_.tc_table);
  return Pipe_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 2, 0, 2>
Pipe::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Pipe, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Pipe_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Pipe>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Pipe, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Pipe, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Pipe, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(Pipe, _impl_.sysno_)}},
    // uint32 flags = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Pipe, _impl_.flags_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(Pipe, _impl_.flags_)}},
    // int32 reader = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Pipe, _impl_.reader_), 4>(),
     {40, 4, 0,
      PROTOBUF_FIELD_OFFSET(Pipe, _impl_.reader_)}},
    // int32 writer = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Pipe, _impl_.writer_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(Pipe, _impl_.writer_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Pipe, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Pipe, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Pipe, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint32 flags = 4;
    {PROTOBUF_FIELD_OFFSET(Pipe, _impl_.flags_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
    // int32 reader = 5;
    {PROTOBUF_FIELD_OFFSET(Pipe, _impl_.reader_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 writer = 6;
    {PROTOBUF_FIELD_OFFSET(Pipe, _impl_.writer_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Pipe::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Pipe)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000003cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.writer_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.writer_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Pipe::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Pipe& this_ = static_cast<const Pipe&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Pipe::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Pipe& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Pipe)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // uint32 flags = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          4, this_._internal_flags(), target);
    }
  }

  // int32 reader = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_reader() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<5>(
              stream, this_._internal_reader(), target);
    }
  }

  // int32 writer = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_writer() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<6>(
              stream, this_._internal_writer(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Pipe)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Pipe::ByteSizeLong(const MessageLite& base) {
  const Pipe& this_ = static_cast<const Pipe&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Pipe::ByteSizeLong() const {
  const Pipe& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Pipe)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // uint32 flags = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_flags());
      }
    }
    // int32 reader = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_reader() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_reader());
      }
    }
    // int32 writer = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_writer() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_writer());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Pipe::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Pipe*>(&to_msg);
  auto& from = static_cast<const Pipe&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Pipe)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_reader() != 0) {
        _this->_impl_.reader_ = from._impl_.reader_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_writer() != 0) {
        _this->_impl_.writer_ = from._impl_.writer_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Pipe::CopyFrom(const Pipe& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Pipe)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Pipe::InternalSwap(Pipe* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Pipe, _impl_.writer_)
      + sizeof(Pipe::_impl_.writer_)
      - PROTOBUF_FIELD_OFFSET(Pipe, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Pipe::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Fcntl::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Fcntl>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Fcntl, _impl_._has_bits_);
};

void Fcntl::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
Fcntl::Fcntl(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Fcntl_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Fcntl)
}
PROTOBUF_NDEBUG_INLINE Fcntl::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Fcntl& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

Fcntl::Fcntl(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Fcntl& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Fcntl_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Fcntl* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, args_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::args_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Fcntl)
}
PROTOBUF_NDEBUG_INLINE Fcntl::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void Fcntl::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, args_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::args_));
}
Fcntl::~Fcntl() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Fcntl)
  SharedDtor(*this);
}
inline void Fcntl::SharedDtor(MessageLite& self) {
  Fcntl& this_ = static_cast<Fcntl&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Fcntl::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Fcntl(arena);
}
constexpr auto Fcntl::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Fcntl),
                                            alignof(Fcntl));
}
constexpr auto Fcntl::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Fcntl_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Fcntl::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Fcntl>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Fcntl::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Fcntl>(), &Fcntl::ByteSizeLong,
              &Fcntl::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Fcntl, _impl_._cached_size_),
          false,
      },
      &Fcntl::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Fcntl_class_data_ =
        Fcntl::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Fcntl::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Fcntl_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Fcntl_class_data_.tc_table);
  return Fcntl_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 36, 2>
Fcntl::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Fcntl, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Fcntl_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Fcntl>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Fcntl, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Fcntl, _impl_.fd_), 4>(),
     {32, 4, 0,
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.fd_path_)}},
    // int32 cmd = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Fcntl, _impl_.cmd_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.cmd_)}},
    // int64 args = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Fcntl, _impl_.args_), 6>(),
     {56, 6, 0,
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.args_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.fd_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // int32 cmd = 6;
    {PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.cmd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int64 args = 7;
    {PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.args_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\24\0\0\0\0\7\0\0"
    "gvisor.syscall.Fcntl"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Fcntl::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Fcntl)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000078U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.args_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.args_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Fcntl::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Fcntl& this_ = static_cast<const Fcntl&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Fcntl::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Fcntl& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Fcntl)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Fcntl.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // int32 cmd = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_cmd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<6>(
              stream, this_._internal_cmd(), target);
    }
  }

  // int64 args = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_args() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<7>(
              stream, this_._internal_args(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Fcntl)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Fcntl::ByteSizeLong(const MessageLite& base) {
  const Fcntl& this_ = static_cast<const Fcntl&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Fcntl::ByteSizeLong() const {
  const Fcntl& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Fcntl)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
    // int32 cmd = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_cmd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_cmd());
      }
    }
    // int64 args = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_args() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_args());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Fcntl::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Fcntl*>(&to_msg);
  auto& from = static_cast<const Fcntl&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Fcntl)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_cmd() != 0) {
        _this->_impl_.cmd_ = from._impl_.cmd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_args() != 0) {
        _this->_impl_.args_ = from._impl_.args_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Fcntl::CopyFrom(const Fcntl& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Fcntl)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Fcntl::InternalSwap(Fcntl* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.args_)
      + sizeof(Fcntl::_impl_.args_)
      - PROTOBUF_FIELD_OFFSET(Fcntl, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Fcntl::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Dup::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Dup>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Dup, _impl_._has_bits_);
};

void Dup::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
Dup::Dup(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Dup_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Dup)
}
PROTOBUF_NDEBUG_INLINE Dup::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Dup& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

Dup::Dup(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Dup& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Dup_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Dup* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Dup)
}
PROTOBUF_NDEBUG_INLINE Dup::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void Dup::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
Dup::~Dup() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Dup)
  SharedDtor(*this);
}
inline void Dup::SharedDtor(MessageLite& self) {
  Dup& this_ = static_cast<Dup&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Dup::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Dup(arena);
}
constexpr auto Dup::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Dup),
                                            alignof(Dup));
}
constexpr auto Dup::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Dup_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Dup::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Dup>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Dup::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Dup>(), &Dup::ByteSizeLong,
              &Dup::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Dup, _impl_._cached_size_),
          false,
      },
      &Dup::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Dup_class_data_ =
        Dup::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Dup::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Dup_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Dup_class_data_.tc_table);
  return Dup_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 34, 2>
Dup::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Dup, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Dup_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Dup>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Dup, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.sysno_)}},
    // int32 old_fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Dup, _impl_.old_fd_), 4>(),
     {32, 4, 0,
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.old_fd_)}},
    // int32 new_fd = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Dup, _impl_.new_fd_), 5>(),
     {40, 5, 0,
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.new_fd_)}},
    // string fd_path = 6;
    {::_pbi::TcParser::FastUS1,
     {50, 0, 0,
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.fd_path_)}},
    // uint32 flags = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Dup, _impl_.flags_), 6>(),
     {56, 6, 0,
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.flags_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Dup, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Dup, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Dup, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 old_fd = 4;
    {PROTOBUF_FIELD_OFFSET(Dup, _impl_.old_fd_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 new_fd = 5;
    {PROTOBUF_FIELD_OFFSET(Dup, _impl_.new_fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 6;
    {PROTOBUF_FIELD_OFFSET(Dup, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // uint32 flags = 7;
    {PROTOBUF_FIELD_OFFSET(Dup, _impl_.flags_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\22\0\0\0\0\0\7\0"
    "gvisor.syscall.Dup"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Dup::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Dup)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000078U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.flags_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.flags_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Dup::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Dup& this_ = static_cast<const Dup&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Dup::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Dup& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Dup)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 old_fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_old_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_old_fd(), target);
    }
  }

  // int32 new_fd = 5;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_new_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<5>(
              stream, this_._internal_new_fd(), target);
    }
  }

  // string fd_path = 6;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Dup.fd_path");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // uint32 flags = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          7, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Dup)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Dup::ByteSizeLong(const MessageLite& base) {
  const Dup& this_ = static_cast<const Dup&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Dup::ByteSizeLong() const {
  const Dup& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Dup)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // string fd_path = 6;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 old_fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_old_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_old_fd());
      }
    }
    // int32 new_fd = 5;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_new_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_new_fd());
      }
    }
    // uint32 flags = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Dup::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Dup*>(&to_msg);
  auto& from = static_cast<const Dup&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Dup)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_old_fd() != 0) {
        _this->_impl_.old_fd_ = from._impl_.old_fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_new_fd() != 0) {
        _this->_impl_.new_fd_ = from._impl_.new_fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Dup::CopyFrom(const Dup& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Dup)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Dup::InternalSwap(Dup* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Dup, _impl_.flags_)
      + sizeof(Dup::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(Dup, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Dup::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Signalfd::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Signalfd>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Signalfd, _impl_._has_bits_);
};

void Signalfd::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
Signalfd::Signalfd(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Signalfd_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Signalfd)
}
PROTOBUF_NDEBUG_INLINE Signalfd::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Signalfd& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

Signalfd::Signalfd(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Signalfd& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Signalfd_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Signalfd* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, sigset_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::sigset_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Signalfd)
}
PROTOBUF_NDEBUG_INLINE Signalfd::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void Signalfd::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, sigset_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::sigset_));
}
Signalfd::~Signalfd() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Signalfd)
  SharedDtor(*this);
}
inline void Signalfd::SharedDtor(MessageLite& self) {
  Signalfd& this_ = static_cast<Signalfd&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Signalfd::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Signalfd(arena);
}
constexpr auto Signalfd::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Signalfd),
                                            alignof(Signalfd));
}
constexpr auto Signalfd::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Signalfd_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Signalfd::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Signalfd>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Signalfd::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Signalfd>(), &Signalfd::ByteSizeLong,
              &Signalfd::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Signalfd, _impl_._cached_size_),
          false,
      },
      &Signalfd::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Signalfd_class_data_ =
        Signalfd::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Signalfd::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Signalfd_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Signalfd_class_data_.tc_table);
  return Signalfd_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 39, 2>
Signalfd::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Signalfd, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Signalfd_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Signalfd>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Signalfd, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Signalfd, _impl_.fd_), 4>(),
     {32, 4, 0,
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.fd_path_)}},
    // uint64 sigset = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Signalfd, _impl_.sigset_), 6>(),
     {48, 6, 0,
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.sigset_)}},
    // int32 flags = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Signalfd, _impl_.flags_), 5>(),
     {56, 5, 0,
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.flags_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.fd_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // uint64 sigset = 6;
    {PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.sigset_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 flags = 7;
    {PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.flags_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\27\0\0\0\0\7\0\0"
    "gvisor.syscall.Signalfd"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Signalfd::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Signalfd)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000078U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.sigset_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.sigset_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Signalfd::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Signalfd& this_ = static_cast<const Signalfd&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Signalfd::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Signalfd& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Signalfd)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Signalfd.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // uint64 sigset = 6;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_sigset() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          6, this_._internal_sigset(), target);
    }
  }

  // int32 flags = 7;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_flags() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<7>(
              stream, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Signalfd)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Signalfd::ByteSizeLong(const MessageLite& base) {
  const Signalfd& this_ = static_cast<const Signalfd&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Signalfd::ByteSizeLong() const {
  const Signalfd& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Signalfd)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
    // int32 flags = 7;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_flags());
      }
    }
    // uint64 sigset = 6;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_sigset() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sigset());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Signalfd::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Signalfd*>(&to_msg);
  auto& from = static_cast<const Signalfd&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Signalfd)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_sigset() != 0) {
        _this->_impl_.sigset_ = from._impl_.sigset_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Signalfd::CopyFrom(const Signalfd& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Signalfd)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Signalfd::InternalSwap(Signalfd* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.sigset_)
      + sizeof(Signalfd::_impl_.sigset_)
      - PROTOBUF_FIELD_OFFSET(Signalfd, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Signalfd::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Chroot::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Chroot>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Chroot, _impl_._has_bits_);
};

void Chroot::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
Chroot::Chroot(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Chroot_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Chroot)
}
PROTOBUF_NDEBUG_INLINE Chroot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Chroot& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        pathname_(arena, from.pathname_) {}

Chroot::Chroot(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Chroot& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Chroot_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Chroot* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  _impl_.sysno_ = from._impl_.sysno_;

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Chroot)
}
PROTOBUF_NDEBUG_INLINE Chroot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        pathname_(arena) {}

inline void Chroot::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, sysno_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::sysno_));
}
Chroot::~Chroot() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Chroot)
  SharedDtor(*this);
}
inline void Chroot::SharedDtor(MessageLite& self) {
  Chroot& this_ = static_cast<Chroot&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.pathname_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Chroot::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Chroot(arena);
}
constexpr auto Chroot::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Chroot),
                                            alignof(Chroot));
}
constexpr auto Chroot::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Chroot_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Chroot::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Chroot>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Chroot::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Chroot>(), &Chroot::ByteSizeLong,
              &Chroot::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Chroot, _impl_._cached_size_),
          false,
      },
      &Chroot::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Chroot_class_data_ =
        Chroot::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Chroot::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Chroot_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Chroot_class_data_.tc_table);
  return Chroot_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<2, 4, 2, 38, 2>
Chroot::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Chroot, _impl_._has_bits_),
    0, // no _extensions_
    4, 24,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967280,  // skipmap
    offsetof(decltype(_table_), field_entries),
    4,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Chroot_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Chroot>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // string pathname = 4;
    {::_pbi::TcParser::FastUS1,
     {34, 0, 0,
      PROTOBUF_FIELD_OFFSET(Chroot, _impl_.pathname_)}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(Chroot, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(Chroot, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Chroot, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(Chroot, _impl_.sysno_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Chroot, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Chroot, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Chroot, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // string pathname = 4;
    {PROTOBUF_FIELD_OFFSET(Chroot, _impl_.pathname_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\25\0\0\0\10\0\0\0"
    "gvisor.syscall.Chroot"
    "pathname"
  }},
};
PROTOBUF_NOINLINE void Chroot::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Chroot)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.pathname_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  _impl_.sysno_ = ::uint64_t{0u};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Chroot::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Chroot& this_ = static_cast<const Chroot&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Chroot::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Chroot& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Chroot)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // string pathname = 4;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_pathname().empty()) {
      const ::std::string& _s = this_._internal_pathname();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Chroot.pathname");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Chroot)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Chroot::ByteSizeLong(const MessageLite& base) {
  const Chroot& this_ = static_cast<const Chroot&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Chroot::ByteSizeLong() const {
  const Chroot& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Chroot)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // string pathname = 4;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_pathname().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_pathname());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Chroot::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Chroot*>(&to_msg);
  auto& from = static_cast<const Chroot&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Chroot)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_pathname().empty()) {
        _this->_internal_set_pathname(from._internal_pathname());
      } else {
        if (_this->_impl_.pathname_.IsDefault()) {
          _this->_internal_set_pathname("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Chroot::CopyFrom(const Chroot& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Chroot)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Chroot::InternalSwap(Chroot* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.pathname_, &other->_impl_.pathname_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Chroot, _impl_.sysno_)
      + sizeof(Chroot::_impl_.sysno_)
      - PROTOBUF_FIELD_OFFSET(Chroot, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Chroot::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Eventfd::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Eventfd>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Eventfd, _impl_._has_bits_);
};

void Eventfd::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Eventfd::Eventfd(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Eventfd_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Eventfd)
}
PROTOBUF_NDEBUG_INLINE Eventfd::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Eventfd& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Eventfd::Eventfd(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Eventfd& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Eventfd_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Eventfd* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Eventfd)
}
PROTOBUF_NDEBUG_INLINE Eventfd::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Eventfd::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
Eventfd::~Eventfd() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Eventfd)
  SharedDtor(*this);
}
inline void Eventfd::SharedDtor(MessageLite& self) {
  Eventfd& this_ = static_cast<Eventfd&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Eventfd::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Eventfd(arena);
}
constexpr auto Eventfd::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Eventfd),
                                            alignof(Eventfd));
}
constexpr auto Eventfd::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Eventfd_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Eventfd::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Eventfd>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Eventfd::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Eventfd>(), &Eventfd::ByteSizeLong,
              &Eventfd::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Eventfd, _impl_._cached_size_),
          false,
      },
      &Eventfd::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Eventfd_class_data_ =
        Eventfd::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Eventfd::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Eventfd_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Eventfd_class_data_.tc_table);
  return Eventfd_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 5, 2, 0, 2>
Eventfd::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Eventfd, _impl_._has_bits_),
    0, // no _extensions_
    5, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967264,  // skipmap
    offsetof(decltype(_table_), field_entries),
    5,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Eventfd_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Eventfd>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Eventfd, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.sysno_)}},
    // int32 val = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Eventfd, _impl_.val_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.val_)}},
    // uint32 flags = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Eventfd, _impl_.flags_), 4>(),
     {40, 4, 0,
      PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.flags_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 val = 4;
    {PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.val_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // uint32 flags = 5;
    {PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.flags_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Eventfd::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Eventfd)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000001cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.flags_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.flags_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Eventfd::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Eventfd& this_ = static_cast<const Eventfd&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Eventfd::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Eventfd& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Eventfd)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 val = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_val() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_val(), target);
    }
  }

  // uint32 flags = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          5, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Eventfd)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Eventfd::ByteSizeLong(const MessageLite& base) {
  const Eventfd& this_ = static_cast<const Eventfd&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Eventfd::ByteSizeLong() const {
  const Eventfd& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Eventfd)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 val = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_val() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_val());
      }
    }
    // uint32 flags = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Eventfd::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Eventfd*>(&to_msg);
  auto& from = static_cast<const Eventfd&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Eventfd)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_val() != 0) {
        _this->_impl_.val_ = from._impl_.val_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Eventfd::CopyFrom(const Eventfd& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Eventfd)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Eventfd::InternalSwap(Eventfd* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.flags_)
      + sizeof(Eventfd::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(Eventfd, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Eventfd::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Clone::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Clone>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Clone, _impl_._has_bits_);
};

void Clone::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Clone::Clone(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Clone_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Clone)
}
PROTOBUF_NDEBUG_INLINE Clone::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Clone& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Clone::Clone(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Clone& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Clone_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Clone* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, tls_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::tls_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Clone)
}
PROTOBUF_NDEBUG_INLINE Clone::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Clone::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, tls_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::tls_));
}
Clone::~Clone() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Clone)
  SharedDtor(*this);
}
inline void Clone::SharedDtor(MessageLite& self) {
  Clone& this_ = static_cast<Clone&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Clone::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Clone(arena);
}
constexpr auto Clone::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Clone),
                                            alignof(Clone));
}
constexpr auto Clone::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Clone_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Clone::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Clone>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Clone::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Clone>(), &Clone::ByteSizeLong,
              &Clone::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Clone, _impl_._cached_size_),
          false,
      },
      &Clone::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Clone_class_data_ =
        Clone::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Clone::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Clone_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Clone_class_data_.tc_table);
  return Clone_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 0, 2>
Clone::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Clone, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Clone_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Clone>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Clone, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.sysno_)}},
    // uint64 flags = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Clone, _impl_.flags_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.flags_)}},
    // uint64 stack = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Clone, _impl_.stack_), 4>(),
     {40, 4, 0,
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.stack_)}},
    // uint64 new_tid = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Clone, _impl_.new_tid_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.new_tid_)}},
    // uint64 tls = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Clone, _impl_.tls_), 6>(),
     {56, 6, 0,
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.tls_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Clone, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Clone, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Clone, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 flags = 4;
    {PROTOBUF_FIELD_OFFSET(Clone, _impl_.flags_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 stack = 5;
    {PROTOBUF_FIELD_OFFSET(Clone, _impl_.stack_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 new_tid = 6;
    {PROTOBUF_FIELD_OFFSET(Clone, _impl_.new_tid_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // uint64 tls = 7;
    {PROTOBUF_FIELD_OFFSET(Clone, _impl_.tls_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Clone::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Clone)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000007cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.tls_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.tls_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Clone::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Clone& this_ = static_cast<const Clone&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Clone::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Clone& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Clone)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // uint64 flags = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_flags() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          4, this_._internal_flags(), target);
    }
  }

  // uint64 stack = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_stack() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          5, this_._internal_stack(), target);
    }
  }

  // uint64 new_tid = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_new_tid() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          6, this_._internal_new_tid(), target);
    }
  }

  // uint64 tls = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_tls() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          7, this_._internal_tls(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Clone)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Clone::ByteSizeLong(const MessageLite& base) {
  const Clone& this_ = static_cast<const Clone&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Clone::ByteSizeLong() const {
  const Clone& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Clone)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // uint64 flags = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_flags());
      }
    }
    // uint64 stack = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_stack() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_stack());
      }
    }
    // uint64 new_tid = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_new_tid() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_new_tid());
      }
    }
    // uint64 tls = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_tls() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_tls());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Clone::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Clone*>(&to_msg);
  auto& from = static_cast<const Clone&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Clone)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_stack() != 0) {
        _this->_impl_.stack_ = from._impl_.stack_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_new_tid() != 0) {
        _this->_impl_.new_tid_ = from._impl_.new_tid_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_tls() != 0) {
        _this->_impl_.tls_ = from._impl_.tls_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Clone::CopyFrom(const Clone& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Clone)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Clone::InternalSwap(Clone* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Clone, _impl_.tls_)
      + sizeof(Clone::_impl_.tls_)
      - PROTOBUF_FIELD_OFFSET(Clone, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Clone::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Bind::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Bind>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Bind, _impl_._has_bits_);
};

void Bind::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
Bind::Bind(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Bind_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Bind)
}
PROTOBUF_NDEBUG_INLINE Bind::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Bind& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_),
        address_(arena, from.address_) {}

Bind::Bind(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Bind& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Bind_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Bind* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, fd_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::fd_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Bind)
}
PROTOBUF_NDEBUG_INLINE Bind::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena),
        address_(arena) {}

inline void Bind::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, fd_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::fd_));
}
Bind::~Bind() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Bind)
  SharedDtor(*this);
}
inline void Bind::SharedDtor(MessageLite& self) {
  Bind& this_ = static_cast<Bind&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  this_._impl_.address_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Bind::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Bind(arena);
}
constexpr auto Bind::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Bind),
                                            alignof(Bind));
}
constexpr auto Bind::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Bind_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Bind::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Bind>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Bind::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Bind>(), &Bind::ByteSizeLong,
              &Bind::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Bind, _impl_._cached_size_),
          false,
      },
      &Bind::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Bind_class_data_ =
        Bind::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Bind::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Bind_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Bind_class_data_.tc_table);
  return Bind_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 2, 35, 2>
Bind::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Bind, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Bind_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Bind>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 2, 0,
      PROTOBUF_FIELD_OFFSET(Bind, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 3, 1,
      PROTOBUF_FIELD_OFFSET(Bind, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Bind, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(Bind, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Bind, _impl_.fd_), 5>(),
     {32, 5, 0,
      PROTOBUF_FIELD_OFFSET(Bind, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Bind, _impl_.fd_path_)}},
    // bytes address = 6;
    {::_pbi::TcParser::FastBS1,
     {50, 1, 0,
      PROTOBUF_FIELD_OFFSET(Bind, _impl_.address_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Bind, _impl_.context_data_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Bind, _impl_.exit_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Bind, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Bind, _impl_.fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Bind, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // bytes address = 6;
    {PROTOBUF_FIELD_OFFSET(Bind, _impl_.address_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\23\0\0\0\0\7\0\0"
    "gvisor.syscall.Bind"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Bind::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Bind)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.address_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000030U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.fd_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.fd_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Bind::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Bind& this_ = static_cast<const Bind&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Bind::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Bind& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Bind)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Bind.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // bytes address = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_address().empty()) {
      const ::std::string& _s = this_._internal_address();
      target = stream->WriteBytesMaybeAliased(6, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Bind)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Bind::ByteSizeLong(const MessageLite& base) {
  const Bind& this_ = static_cast<const Bind&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Bind::ByteSizeLong() const {
  const Bind& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Bind)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // bytes address = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_address().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::BytesSize(
                                        this_._internal_address());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Bind::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Bind*>(&to_msg);
  auto& from = static_cast<const Bind&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Bind)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_address().empty()) {
        _this->_internal_set_address(from._internal_address());
      } else {
        if (_this->_impl_.address_.IsDefault()) {
          _this->_internal_set_address("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Bind::CopyFrom(const Bind& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Bind)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Bind::InternalSwap(Bind* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.address_, &other->_impl_.address_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Bind, _impl_.fd_)
      + sizeof(Bind::_impl_.fd_)
      - PROTOBUF_FIELD_OFFSET(Bind, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Bind::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Accept::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Accept>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Accept, _impl_._has_bits_);
};

void Accept::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
Accept::Accept(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Accept_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Accept)
}
PROTOBUF_NDEBUG_INLINE Accept::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Accept& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_),
        address_(arena, from.address_) {}

Accept::Accept(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Accept& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Accept_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Accept* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Accept)
}
PROTOBUF_NDEBUG_INLINE Accept::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena),
        address_(arena) {}

inline void Accept::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
Accept::~Accept() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Accept)
  SharedDtor(*this);
}
inline void Accept::SharedDtor(MessageLite& self) {
  Accept& this_ = static_cast<Accept&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  this_._impl_.address_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Accept::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Accept(arena);
}
constexpr auto Accept::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Accept),
                                            alignof(Accept));
}
constexpr auto Accept::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Accept_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Accept::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Accept>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Accept::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Accept>(), &Accept::ByteSizeLong,
              &Accept::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Accept, _impl_._cached_size_),
          false,
      },
      &Accept::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Accept_class_data_ =
        Accept::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Accept::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Accept_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Accept_class_data_.tc_table);
  return Accept_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 37, 2>
Accept::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Accept, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Accept_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Accept>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 2, 0,
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 3, 1,
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Accept, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Accept, _impl_.fd_), 5>(),
     {32, 5, 0,
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.fd_path_)}},
    // bytes address = 6;
    {::_pbi::TcParser::FastBS1,
     {50, 1, 0,
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.address_)}},
    // int32 flags = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Accept, _impl_.flags_), 6>(),
     {56, 6, 0,
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.flags_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Accept, _impl_.context_data_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Accept, _impl_.exit_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Accept, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(Accept, _impl_.fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(Accept, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // bytes address = 6;
    {PROTOBUF_FIELD_OFFSET(Accept, _impl_.address_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
    // int32 flags = 7;
    {PROTOBUF_FIELD_OFFSET(Accept, _impl_.flags_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\25\0\0\0\0\7\0\0"
    "gvisor.syscall.Accept"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void Accept::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Accept)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.address_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000070U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.flags_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.flags_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Accept::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Accept& this_ = static_cast<const Accept&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Accept::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Accept& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Accept)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.Accept.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // bytes address = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_address().empty()) {
      const ::std::string& _s = this_._internal_address();
      target = stream->WriteBytesMaybeAliased(6, _s, target);
    }
  }

  // int32 flags = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_flags() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<7>(
              stream, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Accept)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Accept::ByteSizeLong(const MessageLite& base) {
  const Accept& this_ = static_cast<const Accept&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Accept::ByteSizeLong() const {
  const Accept& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Accept)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // bytes address = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_address().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::BytesSize(
                                        this_._internal_address());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
    // int32 flags = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Accept::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Accept*>(&to_msg);
  auto& from = static_cast<const Accept&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Accept)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_address().empty()) {
        _this->_internal_set_address(from._internal_address());
      } else {
        if (_this->_impl_.address_.IsDefault()) {
          _this->_internal_set_address("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Accept::CopyFrom(const Accept& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Accept)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Accept::InternalSwap(Accept* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.address_, &other->_impl_.address_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Accept, _impl_.flags_)
      + sizeof(Accept::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(Accept, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Accept::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class TimerfdCreate::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<TimerfdCreate>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_._has_bits_);
};

void TimerfdCreate::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
TimerfdCreate::TimerfdCreate(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, TimerfdCreate_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.TimerfdCreate)
}
PROTOBUF_NDEBUG_INLINE TimerfdCreate::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::TimerfdCreate& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

TimerfdCreate::TimerfdCreate(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const TimerfdCreate& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, TimerfdCreate_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  TimerfdCreate* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.TimerfdCreate)
}
PROTOBUF_NDEBUG_INLINE TimerfdCreate::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void TimerfdCreate::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
TimerfdCreate::~TimerfdCreate() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.TimerfdCreate)
  SharedDtor(*this);
}
inline void TimerfdCreate::SharedDtor(MessageLite& self) {
  TimerfdCreate& this_ = static_cast<TimerfdCreate&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL TimerfdCreate::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) TimerfdCreate(arena);
}
constexpr auto TimerfdCreate::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(TimerfdCreate),
                                            alignof(TimerfdCreate));
}
constexpr auto TimerfdCreate::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_TimerfdCreate_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &TimerfdCreate::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<TimerfdCreate>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &TimerfdCreate::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<TimerfdCreate>(), &TimerfdCreate::ByteSizeLong,
              &TimerfdCreate::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_._cached_size_),
          false,
      },
      &TimerfdCreate::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull TimerfdCreate_class_data_ =
        TimerfdCreate::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
TimerfdCreate::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&TimerfdCreate_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(TimerfdCreate_class_data_.tc_table);
  return TimerfdCreate_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 5, 2, 0, 2>
TimerfdCreate::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_._has_bits_),
    0, // no _extensions_
    5, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967264,  // skipmap
    offsetof(decltype(_table_), field_entries),
    5,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    TimerfdCreate_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::TimerfdCreate>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(TimerfdCreate, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.sysno_)}},
    // int32 clock_id = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(TimerfdCreate, _impl_.clock_id_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.clock_id_)}},
    // int32 flags = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(TimerfdCreate, _impl_.flags_), 4>(),
     {40, 4, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.flags_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 clock_id = 4;
    {PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.clock_id_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 flags = 5;
    {PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.flags_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void TimerfdCreate::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.TimerfdCreate)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000001cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.flags_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.flags_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL TimerfdCreate::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const TimerfdCreate& this_ = static_cast<const TimerfdCreate&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL TimerfdCreate::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const TimerfdCreate& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.TimerfdCreate)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 clock_id = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_clock_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_clock_id(), target);
    }
  }

  // int32 flags = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_flags() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<5>(
              stream, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.TimerfdCreate)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t TimerfdCreate::ByteSizeLong(const MessageLite& base) {
  const TimerfdCreate& this_ = static_cast<const TimerfdCreate&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t TimerfdCreate::ByteSizeLong() const {
  const TimerfdCreate& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.TimerfdCreate)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 clock_id = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_clock_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_clock_id());
      }
    }
    // int32 flags = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void TimerfdCreate::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<TimerfdCreate*>(&to_msg);
  auto& from = static_cast<const TimerfdCreate&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.TimerfdCreate)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_clock_id() != 0) {
        _this->_impl_.clock_id_ = from._impl_.clock_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void TimerfdCreate::CopyFrom(const TimerfdCreate& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.TimerfdCreate)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void TimerfdCreate::InternalSwap(TimerfdCreate* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.flags_)
      + sizeof(TimerfdCreate::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(TimerfdCreate, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata TimerfdCreate::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Timespec::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Timespec>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Timespec, _impl_._has_bits_);
};

Timespec::Timespec(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Timespec_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Timespec)
}
Timespec::Timespec(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Timespec& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Timespec_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE Timespec::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Timespec::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sec_),
           0,
           offsetof(Impl_, nsec_) -
               offsetof(Impl_, sec_) +
               sizeof(Impl_::nsec_));
}
Timespec::~Timespec() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Timespec)
  SharedDtor(*this);
}
inline void Timespec::SharedDtor(MessageLite& self) {
  Timespec& this_ = static_cast<Timespec&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Timespec::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Timespec(arena);
}
constexpr auto Timespec::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Timespec),
                                            alignof(Timespec));
}
constexpr auto Timespec::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Timespec_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Timespec::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Timespec>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Timespec::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Timespec>(), &Timespec::ByteSizeLong,
              &Timespec::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Timespec, _impl_._cached_size_),
          false,
      },
      &Timespec::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Timespec_class_data_ =
        Timespec::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Timespec::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Timespec_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Timespec_class_data_.tc_table);
  return Timespec_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 0, 0, 2>
Timespec::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Timespec, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    Timespec_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Timespec>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // int64 nsec = 2;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Timespec, _impl_.nsec_), 1>(),
     {16, 1, 0,
      PROTOBUF_FIELD_OFFSET(Timespec, _impl_.nsec_)}},
    // int64 sec = 1;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Timespec, _impl_.sec_), 0>(),
     {8, 0, 0,
      PROTOBUF_FIELD_OFFSET(Timespec, _impl_.sec_)}},
  }}, {{
    65535, 65535
  }}, {{
    // int64 sec = 1;
    {PROTOBUF_FIELD_OFFSET(Timespec, _impl_.sec_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // int64 nsec = 2;
    {PROTOBUF_FIELD_OFFSET(Timespec, _impl_.nsec_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
  }},
  // no aux_entries
  {{
  }},
};
PROTOBUF_NOINLINE void Timespec::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Timespec)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    ::memset(&_impl_.sec_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.nsec_) -
        reinterpret_cast<char*>(&_impl_.sec_)) + sizeof(_impl_.nsec_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Timespec::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Timespec& this_ = static_cast<const Timespec&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Timespec::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Timespec& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Timespec)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // int64 sec = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (this_._internal_sec() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<1>(
              stream, this_._internal_sec(), target);
    }
  }

  // int64 nsec = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_nsec() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<2>(
              stream, this_._internal_nsec(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Timespec)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Timespec::ByteSizeLong(const MessageLite& base) {
  const Timespec& this_ = static_cast<const Timespec&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Timespec::ByteSizeLong() const {
  const Timespec& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Timespec)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // int64 sec = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (this_._internal_sec() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_sec());
      }
    }
    // int64 nsec = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_nsec() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_nsec());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Timespec::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Timespec*>(&to_msg);
  auto& from = static_cast<const Timespec&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Timespec)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (from._internal_sec() != 0) {
        _this->_impl_.sec_ = from._impl_.sec_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_nsec() != 0) {
        _this->_impl_.nsec_ = from._impl_.nsec_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Timespec::CopyFrom(const Timespec& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Timespec)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Timespec::InternalSwap(Timespec* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Timespec, _impl_.nsec_)
      + sizeof(Timespec::_impl_.nsec_)
      - PROTOBUF_FIELD_OFFSET(Timespec, _impl_.sec_)>(
          reinterpret_cast<char*>(&_impl_.sec_),
          reinterpret_cast<char*>(&other->_impl_.sec_));
}

::google::protobuf::Metadata Timespec::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class ItimerSpec::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<ItimerSpec>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_._has_bits_);
};

ItimerSpec::ItimerSpec(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ItimerSpec_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.ItimerSpec)
}
PROTOBUF_NDEBUG_INLINE ItimerSpec::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::ItimerSpec& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

ItimerSpec::ItimerSpec(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ItimerSpec& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ItimerSpec_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ItimerSpec* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.interval_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.interval_)
                : nullptr;
  _impl_.value_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.ItimerSpec)
}
PROTOBUF_NDEBUG_INLINE ItimerSpec::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ItimerSpec::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, interval_),
           0,
           offsetof(Impl_, value_) -
               offsetof(Impl_, interval_) +
               sizeof(Impl_::value_));
}
ItimerSpec::~ItimerSpec() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.ItimerSpec)
  SharedDtor(*this);
}
inline void ItimerSpec::SharedDtor(MessageLite& self) {
  ItimerSpec& this_ = static_cast<ItimerSpec&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.interval_;
  delete this_._impl_.value_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL ItimerSpec::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ItimerSpec(arena);
}
constexpr auto ItimerSpec::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ItimerSpec),
                                            alignof(ItimerSpec));
}
constexpr auto ItimerSpec::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_ItimerSpec_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &ItimerSpec::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ItimerSpec>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ItimerSpec::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ItimerSpec>(), &ItimerSpec::ByteSizeLong,
              &ItimerSpec::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_._cached_size_),
          false,
      },
      &ItimerSpec::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ItimerSpec_class_data_ =
        ItimerSpec::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ItimerSpec::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ItimerSpec_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ItimerSpec_class_data_.tc_table);
  return ItimerSpec_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 2, 0, 2>
ItimerSpec::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    ItimerSpec_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::ItimerSpec>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // .gvisor.syscall.Timespec value = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_.value_)}},
    // .gvisor.syscall.Timespec interval = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_.interval_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.syscall.Timespec interval = 1;
    {PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_.interval_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Timespec value = 2;
    {PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_.value_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Timespec>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Timespec>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void ItimerSpec::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.ItimerSpec)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.interval_ != nullptr);
      _impl_.interval_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.value_ != nullptr);
      _impl_.value_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ItimerSpec::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ItimerSpec& this_ = static_cast<const ItimerSpec&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ItimerSpec::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ItimerSpec& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.ItimerSpec)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.syscall.Timespec interval = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.interval_, this_._impl_.interval_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Timespec value = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.value_, this_._impl_.value_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.ItimerSpec)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ItimerSpec::ByteSizeLong(const MessageLite& base) {
  const ItimerSpec& this_ = static_cast<const ItimerSpec&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ItimerSpec::ByteSizeLong() const {
  const ItimerSpec& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.ItimerSpec)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // .gvisor.syscall.Timespec interval = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.interval_);
    }
    // .gvisor.syscall.Timespec value = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.value_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ItimerSpec::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<ItimerSpec*>(&to_msg);
  auto& from = static_cast<const ItimerSpec&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.ItimerSpec)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.interval_ != nullptr);
      if (_this->_impl_.interval_ == nullptr) {
        _this->_impl_.interval_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.interval_);
      } else {
        _this->_impl_.interval_->MergeFrom(*from._impl_.interval_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.value_ != nullptr);
      if (_this->_impl_.value_ == nullptr) {
        _this->_impl_.value_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.value_);
      } else {
        _this->_impl_.value_->MergeFrom(*from._impl_.value_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ItimerSpec::CopyFrom(const ItimerSpec& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.ItimerSpec)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ItimerSpec::InternalSwap(ItimerSpec* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_.value_)
      + sizeof(ItimerSpec::_impl_.value_)
      - PROTOBUF_FIELD_OFFSET(ItimerSpec, _impl_.interval_)>(
          reinterpret_cast<char*>(&_impl_.interval_),
          reinterpret_cast<char*>(&other->_impl_.interval_));
}

::google::protobuf::Metadata ItimerSpec::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class TimerfdSetTime::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<TimerfdSetTime>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_._has_bits_);
};

void TimerfdSetTime::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
TimerfdSetTime::TimerfdSetTime(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, TimerfdSetTime_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.TimerfdSetTime)
}
PROTOBUF_NDEBUG_INLINE TimerfdSetTime::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::TimerfdSetTime& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

TimerfdSetTime::TimerfdSetTime(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const TimerfdSetTime& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, TimerfdSetTime_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  TimerfdSetTime* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  _impl_.new_value_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.new_value_)
                : nullptr;
  _impl_.old_value_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.old_value_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.TimerfdSetTime)
}
PROTOBUF_NDEBUG_INLINE TimerfdSetTime::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void TimerfdSetTime::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
TimerfdSetTime::~TimerfdSetTime() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.TimerfdSetTime)
  SharedDtor(*this);
}
inline void TimerfdSetTime::SharedDtor(MessageLite& self) {
  TimerfdSetTime& this_ = static_cast<TimerfdSetTime&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  delete this_._impl_.new_value_;
  delete this_._impl_.old_value_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL TimerfdSetTime::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) TimerfdSetTime(arena);
}
constexpr auto TimerfdSetTime::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(TimerfdSetTime),
                                            alignof(TimerfdSetTime));
}
constexpr auto TimerfdSetTime::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_TimerfdSetTime_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &TimerfdSetTime::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<TimerfdSetTime>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &TimerfdSetTime::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<TimerfdSetTime>(), &TimerfdSetTime::ByteSizeLong,
              &TimerfdSetTime::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_._cached_size_),
          false,
      },
      &TimerfdSetTime::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull TimerfdSetTime_class_data_ =
        TimerfdSetTime::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
TimerfdSetTime::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&TimerfdSetTime_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(TimerfdSetTime_class_data_.tc_table);
  return TimerfdSetTime_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 8, 4, 53, 2>
TimerfdSetTime::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_._has_bits_),
    0, // no _extensions_
    8, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967040,  // skipmap
    offsetof(decltype(_table_), field_entries),
    8,  // num_field_entries
    4,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    TimerfdSetTime_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::TimerfdSetTime>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // .gvisor.syscall.ItimerSpec old_value = 8;
    {::_pbi::TcParser::FastMtS1,
     {66, 4, 3,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.old_value_)}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(TimerfdSetTime, _impl_.sysno_), 5>(),
     {24, 5, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(TimerfdSetTime, _impl_.fd_), 6>(),
     {32, 6, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.fd_path_)}},
    // int32 flags = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(TimerfdSetTime, _impl_.flags_), 7>(),
     {48, 7, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.flags_)}},
    // .gvisor.syscall.ItimerSpec new_value = 7;
    {::_pbi::TcParser::FastMtS1,
     {58, 3, 2,
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.new_value_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.sysno_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.fd_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // int32 flags = 6;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.flags_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // .gvisor.syscall.ItimerSpec new_value = 7;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.new_value_), _Internal::kHasBitsOffset + 3, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.ItimerSpec old_value = 8;
    {PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.old_value_), _Internal::kHasBitsOffset + 4, 3, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::ItimerSpec>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::ItimerSpec>()},
  }},
  {{
    "\35\0\0\0\0\7\0\0\0\0\0\0\0\0\0\0"
    "gvisor.syscall.TimerfdSetTime"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void TimerfdSetTime::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.TimerfdSetTime)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.new_value_ != nullptr);
      _impl_.new_value_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.old_value_ != nullptr);
      _impl_.old_value_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000e0U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.flags_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.flags_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL TimerfdSetTime::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const TimerfdSetTime& this_ = static_cast<const TimerfdSetTime&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL TimerfdSetTime::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const TimerfdSetTime& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.TimerfdSetTime)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.TimerfdSetTime.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // int32 flags = 6;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_flags() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<6>(
              stream, this_._internal_flags(), target);
    }
  }

  // .gvisor.syscall.ItimerSpec new_value = 7;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        7, *this_._impl_.new_value_, this_._impl_.new_value_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.ItimerSpec old_value = 8;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        8, *this_._impl_.old_value_, this_._impl_.old_value_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.TimerfdSetTime)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t TimerfdSetTime::ByteSizeLong(const MessageLite& base) {
  const TimerfdSetTime& this_ = static_cast<const TimerfdSetTime&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t TimerfdSetTime::ByteSizeLong() const {
  const TimerfdSetTime& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.TimerfdSetTime)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // .gvisor.syscall.ItimerSpec new_value = 7;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.new_value_);
    }
    // .gvisor.syscall.ItimerSpec old_value = 8;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.old_value_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
    // int32 flags = 6;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void TimerfdSetTime::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<TimerfdSetTime*>(&to_msg);
  auto& from = static_cast<const TimerfdSetTime&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.TimerfdSetTime)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.new_value_ != nullptr);
      if (_this->_impl_.new_value_ == nullptr) {
        _this->_impl_.new_value_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.new_value_);
      } else {
        _this->_impl_.new_value_->MergeFrom(*from._impl_.new_value_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.old_value_ != nullptr);
      if (_this->_impl_.old_value_ == nullptr) {
        _this->_impl_.old_value_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.old_value_);
      } else {
        _this->_impl_.old_value_->MergeFrom(*from._impl_.old_value_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void TimerfdSetTime::CopyFrom(const TimerfdSetTime& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.TimerfdSetTime)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void TimerfdSetTime::InternalSwap(TimerfdSetTime* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.flags_)
      + sizeof(TimerfdSetTime::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(TimerfdSetTime, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata TimerfdSetTime::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class TimerfdGetTime::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<TimerfdGetTime>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_._has_bits_);
};

void TimerfdGetTime::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
TimerfdGetTime::TimerfdGetTime(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, TimerfdGetTime_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.TimerfdGetTime)
}
PROTOBUF_NDEBUG_INLINE TimerfdGetTime::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::TimerfdGetTime& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

TimerfdGetTime::TimerfdGetTime(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const TimerfdGetTime& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, TimerfdGetTime_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  TimerfdGetTime* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  _impl_.cur_value_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.cur_value_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, fd_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::fd_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.TimerfdGetTime)
}
PROTOBUF_NDEBUG_INLINE TimerfdGetTime::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void TimerfdGetTime::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, fd_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::fd_));
}
TimerfdGetTime::~TimerfdGetTime() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.TimerfdGetTime)
  SharedDtor(*this);
}
inline void TimerfdGetTime::SharedDtor(MessageLite& self) {
  TimerfdGetTime& this_ = static_cast<TimerfdGetTime&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  delete this_._impl_.cur_value_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL TimerfdGetTime::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) TimerfdGetTime(arena);
}
constexpr auto TimerfdGetTime::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(TimerfdGetTime),
                                            alignof(TimerfdGetTime));
}
constexpr auto TimerfdGetTime::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_TimerfdGetTime_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &TimerfdGetTime::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<TimerfdGetTime>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &TimerfdGetTime::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<TimerfdGetTime>(), &TimerfdGetTime::ByteSizeLong,
              &TimerfdGetTime::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_._cached_size_),
          false,
      },
      &TimerfdGetTime::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull TimerfdGetTime_class_data_ =
        TimerfdGetTime::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
TimerfdGetTime::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&TimerfdGetTime_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(TimerfdGetTime_class_data_.tc_table);
  return TimerfdGetTime_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 3, 45, 2>
TimerfdGetTime::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    3,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    TimerfdGetTime_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::TimerfdGetTime>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(TimerfdGetTime, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(TimerfdGetTime, _impl_.fd_), 5>(),
     {32, 5, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.fd_path_)}},
    // .gvisor.syscall.ItimerSpec cur_value = 6;
    {::_pbi::TcParser::FastMtS1,
     {50, 3, 2,
      PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.cur_value_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .gvisor.syscall.ItimerSpec cur_value = 6;
    {PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.cur_value_), _Internal::kHasBitsOffset + 3, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::ItimerSpec>()},
  }},
  {{
    "\35\0\0\0\0\7\0\0"
    "gvisor.syscall.TimerfdGetTime"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void TimerfdGetTime::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.TimerfdGetTime)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.cur_value_ != nullptr);
      _impl_.cur_value_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000030U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.fd_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.fd_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL TimerfdGetTime::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const TimerfdGetTime& this_ = static_cast<const TimerfdGetTime&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL TimerfdGetTime::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const TimerfdGetTime& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.TimerfdGetTime)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.TimerfdGetTime.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // .gvisor.syscall.ItimerSpec cur_value = 6;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        6, *this_._impl_.cur_value_, this_._impl_.cur_value_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.TimerfdGetTime)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t TimerfdGetTime::ByteSizeLong(const MessageLite& base) {
  const TimerfdGetTime& this_ = static_cast<const TimerfdGetTime&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t TimerfdGetTime::ByteSizeLong() const {
  const TimerfdGetTime& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.TimerfdGetTime)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // .gvisor.syscall.ItimerSpec cur_value = 6;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.cur_value_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void TimerfdGetTime::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<TimerfdGetTime*>(&to_msg);
  auto& from = static_cast<const TimerfdGetTime&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.TimerfdGetTime)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.cur_value_ != nullptr);
      if (_this->_impl_.cur_value_ == nullptr) {
        _this->_impl_.cur_value_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.cur_value_);
      } else {
        _this->_impl_.cur_value_->MergeFrom(*from._impl_.cur_value_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void TimerfdGetTime::CopyFrom(const TimerfdGetTime& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.TimerfdGetTime)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void TimerfdGetTime::InternalSwap(TimerfdGetTime* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.fd_)
      + sizeof(TimerfdGetTime::_impl_.fd_)
      - PROTOBUF_FIELD_OFFSET(TimerfdGetTime, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata TimerfdGetTime::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class Fork::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<Fork>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Fork, _impl_._has_bits_);
};

void Fork::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
Fork::Fork(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Fork_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.Fork)
}
PROTOBUF_NDEBUG_INLINE Fork::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::Fork& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Fork::Fork(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Fork& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Fork_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Fork* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  _impl_.sysno_ = from._impl_.sysno_;

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.Fork)
}
PROTOBUF_NDEBUG_INLINE Fork::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Fork::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, sysno_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::sysno_));
}
Fork::~Fork() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.Fork)
  SharedDtor(*this);
}
inline void Fork::SharedDtor(MessageLite& self) {
  Fork& this_ = static_cast<Fork&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL Fork::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Fork(arena);
}
constexpr auto Fork::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Fork),
                                            alignof(Fork));
}
constexpr auto Fork::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_Fork_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &Fork::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Fork>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Fork::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Fork>(), &Fork::ByteSizeLong,
              &Fork::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Fork, _impl_._cached_size_),
          false,
      },
      &Fork::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Fork_class_data_ =
        Fork::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Fork::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Fork_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Fork_class_data_.tc_table);
  return Fork_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<2, 3, 2, 0, 2>
Fork::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(Fork, _impl_._has_bits_),
    0, // no _extensions_
    3, 24,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967288,  // skipmap
    offsetof(decltype(_table_), field_entries),
    3,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    Fork_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::Fork>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(Fork, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(Fork, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Fork, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(Fork, _impl_.sysno_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(Fork, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(Fork, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(Fork, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void Fork::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.Fork)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  _impl_.sysno_ = ::uint64_t{0u};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Fork::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Fork& this_ = static_cast<const Fork&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Fork::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Fork& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.Fork)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.Fork)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Fork::ByteSizeLong(const MessageLite& base) {
  const Fork& this_ = static_cast<const Fork&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Fork::ByteSizeLong() const {
  const Fork& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.Fork)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Fork::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<Fork*>(&to_msg);
  auto& from = static_cast<const Fork&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.Fork)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Fork::CopyFrom(const Fork& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.Fork)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Fork::InternalSwap(Fork* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Fork, _impl_.sysno_)
      + sizeof(Fork::_impl_.sysno_)
      - PROTOBUF_FIELD_OFFSET(Fork, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata Fork::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class InotifyInit::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<InotifyInit>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_._has_bits_);
};

void InotifyInit::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
InotifyInit::InotifyInit(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, InotifyInit_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.InotifyInit)
}
PROTOBUF_NDEBUG_INLINE InotifyInit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::InotifyInit& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

InotifyInit::InotifyInit(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const InotifyInit& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, InotifyInit_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  InotifyInit* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, flags_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::flags_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.InotifyInit)
}
PROTOBUF_NDEBUG_INLINE InotifyInit::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void InotifyInit::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, flags_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::flags_));
}
InotifyInit::~InotifyInit() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.InotifyInit)
  SharedDtor(*this);
}
inline void InotifyInit::SharedDtor(MessageLite& self) {
  InotifyInit& this_ = static_cast<InotifyInit&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL InotifyInit::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) InotifyInit(arena);
}
constexpr auto InotifyInit::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(InotifyInit),
                                            alignof(InotifyInit));
}
constexpr auto InotifyInit::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_InotifyInit_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &InotifyInit::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<InotifyInit>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &InotifyInit::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<InotifyInit>(), &InotifyInit::ByteSizeLong,
              &InotifyInit::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_._cached_size_),
          false,
      },
      &InotifyInit::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull InotifyInit_class_data_ =
        InotifyInit::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
InotifyInit::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&InotifyInit_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(InotifyInit_class_data_.tc_table);
  return InotifyInit_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<2, 4, 2, 0, 2>
InotifyInit::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_._has_bits_),
    0, // no _extensions_
    4, 24,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967280,  // skipmap
    offsetof(decltype(_table_), field_entries),
    4,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    InotifyInit_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::InotifyInit>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // int32 flags = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(InotifyInit, _impl_.flags_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.flags_)}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(InotifyInit, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.sysno_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 flags = 4;
    {PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.flags_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void InotifyInit::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.InotifyInit)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000000cU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.flags_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.flags_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL InotifyInit::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const InotifyInit& this_ = static_cast<const InotifyInit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL InotifyInit::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const InotifyInit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.InotifyInit)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 flags = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_flags() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_flags(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.InotifyInit)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t InotifyInit::ByteSizeLong(const MessageLite& base) {
  const InotifyInit& this_ = static_cast<const InotifyInit&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t InotifyInit::ByteSizeLong() const {
  const InotifyInit& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.InotifyInit)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 flags = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_flags() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_flags());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void InotifyInit::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<InotifyInit*>(&to_msg);
  auto& from = static_cast<const InotifyInit&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.InotifyInit)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_flags() != 0) {
        _this->_impl_.flags_ = from._impl_.flags_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void InotifyInit::CopyFrom(const InotifyInit& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.InotifyInit)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void InotifyInit::InternalSwap(InotifyInit* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.flags_)
      + sizeof(InotifyInit::_impl_.flags_)
      - PROTOBUF_FIELD_OFFSET(InotifyInit, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata InotifyInit::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class InotifyAddWatch::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<InotifyAddWatch>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_._has_bits_);
};

void InotifyAddWatch::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
InotifyAddWatch::InotifyAddWatch(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, InotifyAddWatch_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.InotifyAddWatch)
}
PROTOBUF_NDEBUG_INLINE InotifyAddWatch::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::InotifyAddWatch& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_),
        pathname_(arena, from.pathname_) {}

InotifyAddWatch::InotifyAddWatch(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const InotifyAddWatch& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, InotifyAddWatch_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  InotifyAddWatch* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, mask_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::mask_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.InotifyAddWatch)
}
PROTOBUF_NDEBUG_INLINE InotifyAddWatch::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena),
        pathname_(arena) {}

inline void InotifyAddWatch::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, mask_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::mask_));
}
InotifyAddWatch::~InotifyAddWatch() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.InotifyAddWatch)
  SharedDtor(*this);
}
inline void InotifyAddWatch::SharedDtor(MessageLite& self) {
  InotifyAddWatch& this_ = static_cast<InotifyAddWatch&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  this_._impl_.pathname_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL InotifyAddWatch::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) InotifyAddWatch(arena);
}
constexpr auto InotifyAddWatch::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(InotifyAddWatch),
                                            alignof(InotifyAddWatch));
}
constexpr auto InotifyAddWatch::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_InotifyAddWatch_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &InotifyAddWatch::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<InotifyAddWatch>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &InotifyAddWatch::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<InotifyAddWatch>(), &InotifyAddWatch::ByteSizeLong,
              &InotifyAddWatch::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_._cached_size_),
          false,
      },
      &InotifyAddWatch::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull InotifyAddWatch_class_data_ =
        InotifyAddWatch::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
InotifyAddWatch::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&InotifyAddWatch_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(InotifyAddWatch_class_data_.tc_table);
  return InotifyAddWatch_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 54, 2>
InotifyAddWatch::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    InotifyAddWatch_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::InotifyAddWatch>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 2, 0,
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 3, 1,
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(InotifyAddWatch, _impl_.sysno_), 4>(),
     {24, 4, 0,
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(InotifyAddWatch, _impl_.fd_), 5>(),
     {32, 5, 0,
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.fd_path_)}},
    // string pathname = 6;
    {::_pbi::TcParser::FastUS1,
     {50, 1, 0,
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.pathname_)}},
    // uint32 mask = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(InotifyAddWatch, _impl_.mask_), 6>(),
     {56, 6, 0,
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.mask_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.context_data_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.exit_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.sysno_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.fd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string pathname = 6;
    {PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.pathname_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // uint32 mask = 7;
    {PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.mask_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\36\0\0\0\0\7\10\0"
    "gvisor.syscall.InotifyAddWatch"
    "fd_path"
    "pathname"
  }},
};
PROTOBUF_NOINLINE void InotifyAddWatch::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.InotifyAddWatch)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.pathname_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000070U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.mask_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.mask_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL InotifyAddWatch::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const InotifyAddWatch& this_ = static_cast<const InotifyAddWatch&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL InotifyAddWatch::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const InotifyAddWatch& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.InotifyAddWatch)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.InotifyAddWatch.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string pathname = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_pathname().empty()) {
      const ::std::string& _s = this_._internal_pathname();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.InotifyAddWatch.pathname");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // uint32 mask = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_mask() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          7, this_._internal_mask(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.InotifyAddWatch)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t InotifyAddWatch::ByteSizeLong(const MessageLite& base) {
  const InotifyAddWatch& this_ = static_cast<const InotifyAddWatch&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t InotifyAddWatch::ByteSizeLong() const {
  const InotifyAddWatch& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.InotifyAddWatch)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // string pathname = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_pathname().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_pathname());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
    // uint32 mask = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_mask() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_mask());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void InotifyAddWatch::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<InotifyAddWatch*>(&to_msg);
  auto& from = static_cast<const InotifyAddWatch&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.InotifyAddWatch)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_pathname().empty()) {
        _this->_internal_set_pathname(from._internal_pathname());
      } else {
        if (_this->_impl_.pathname_.IsDefault()) {
          _this->_internal_set_pathname("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_mask() != 0) {
        _this->_impl_.mask_ = from._impl_.mask_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void InotifyAddWatch::CopyFrom(const InotifyAddWatch& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.InotifyAddWatch)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void InotifyAddWatch::InternalSwap(InotifyAddWatch* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.pathname_, &other->_impl_.pathname_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.mask_)
      + sizeof(InotifyAddWatch::_impl_.mask_)
      - PROTOBUF_FIELD_OFFSET(InotifyAddWatch, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata InotifyAddWatch::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class InotifyRmWatch::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<InotifyRmWatch>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_._has_bits_);
};

void InotifyRmWatch::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
InotifyRmWatch::InotifyRmWatch(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, InotifyRmWatch_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.InotifyRmWatch)
}
PROTOBUF_NDEBUG_INLINE InotifyRmWatch::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::InotifyRmWatch& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        fd_path_(arena, from.fd_path_) {}

InotifyRmWatch::InotifyRmWatch(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const InotifyRmWatch& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, InotifyRmWatch_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  InotifyRmWatch* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, wd_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::wd_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.InotifyRmWatch)
}
PROTOBUF_NDEBUG_INLINE InotifyRmWatch::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        fd_path_(arena) {}

inline void InotifyRmWatch::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, wd_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::wd_));
}
InotifyRmWatch::~InotifyRmWatch() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.InotifyRmWatch)
  SharedDtor(*this);
}
inline void InotifyRmWatch::SharedDtor(MessageLite& self) {
  InotifyRmWatch& this_ = static_cast<InotifyRmWatch&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.fd_path_.Destroy();
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL InotifyRmWatch::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) InotifyRmWatch(arena);
}
constexpr auto InotifyRmWatch::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(InotifyRmWatch),
                                            alignof(InotifyRmWatch));
}
constexpr auto InotifyRmWatch::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_InotifyRmWatch_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &InotifyRmWatch::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<InotifyRmWatch>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &InotifyRmWatch::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<InotifyRmWatch>(), &InotifyRmWatch::ByteSizeLong,
              &InotifyRmWatch::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_._cached_size_),
          false,
      },
      &InotifyRmWatch::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull InotifyRmWatch_class_data_ =
        InotifyRmWatch::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
InotifyRmWatch::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&InotifyRmWatch_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(InotifyRmWatch_class_data_.tc_table);
  return InotifyRmWatch_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 2, 45, 2>
InotifyRmWatch::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    InotifyRmWatch_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::InotifyRmWatch>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 1, 0,
      PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 2, 1,
      PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(InotifyRmWatch, _impl_.sysno_), 3>(),
     {24, 3, 0,
      PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.sysno_)}},
    // int32 fd = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(InotifyRmWatch, _impl_.fd_), 4>(),
     {32, 4, 0,
      PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.fd_)}},
    // string fd_path = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 0, 0,
      PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.fd_path_)}},
    // int32 wd = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(InotifyRmWatch, _impl_.wd_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.wd_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.context_data_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.exit_), _Internal::kHasBitsOffset + 2, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.sysno_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 fd = 4;
    {PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.fd_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string fd_path = 5;
    {PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.fd_path_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // int32 wd = 6;
    {PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.wd_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
    "\35\0\0\0\0\7\0\0"
    "gvisor.syscall.InotifyRmWatch"
    "fd_path"
  }},
};
PROTOBUF_NOINLINE void InotifyRmWatch::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.InotifyRmWatch)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.fd_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000038U)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.wd_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.wd_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL InotifyRmWatch::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const InotifyRmWatch& this_ = static_cast<const InotifyRmWatch&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL InotifyRmWatch::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const InotifyRmWatch& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.InotifyRmWatch)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 fd = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_fd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_fd(), target);
    }
  }

  // string fd_path = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_fd_path().empty()) {
      const ::std::string& _s = this_._internal_fd_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "gvisor.syscall.InotifyRmWatch.fd_path");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // int32 wd = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_wd() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<6>(
              stream, this_._internal_wd(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.InotifyRmWatch)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t InotifyRmWatch::ByteSizeLong(const MessageLite& base) {
  const InotifyRmWatch& this_ = static_cast<const InotifyRmWatch&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t InotifyRmWatch::ByteSizeLong() const {
  const InotifyRmWatch& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.InotifyRmWatch)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    // string fd_path = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_fd_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_fd_path());
      }
    }
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 fd = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_fd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_fd());
      }
    }
    // int32 wd = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_wd() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_wd());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void InotifyRmWatch::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<InotifyRmWatch*>(&to_msg);
  auto& from = static_cast<const InotifyRmWatch&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.InotifyRmWatch)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000003fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_fd_path().empty()) {
        _this->_internal_set_fd_path(from._internal_fd_path());
      } else {
        if (_this->_impl_.fd_path_.IsDefault()) {
          _this->_internal_set_fd_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_fd() != 0) {
        _this->_impl_.fd_ = from._impl_.fd_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_wd() != 0) {
        _this->_impl_.wd_ = from._impl_.wd_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void InotifyRmWatch::CopyFrom(const InotifyRmWatch& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.InotifyRmWatch)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void InotifyRmWatch::InternalSwap(InotifyRmWatch* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.fd_path_, &other->_impl_.fd_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.wd_)
      + sizeof(InotifyRmWatch::_impl_.wd_)
      - PROTOBUF_FIELD_OFFSET(InotifyRmWatch, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata InotifyRmWatch::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class SocketPair::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<SocketPair>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(SocketPair, _impl_._has_bits_);
};

void SocketPair::clear_context_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.context_data_ != nullptr) _impl_.context_data_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
SocketPair::SocketPair(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SocketPair_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:gvisor.syscall.SocketPair)
}
PROTOBUF_NDEBUG_INLINE SocketPair::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::gvisor::syscall::SocketPair& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

SocketPair::SocketPair(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const SocketPair& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SocketPair_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SocketPair* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.context_data_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_)
                : nullptr;
  _impl_.exit_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, sysno_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, sysno_),
           offsetof(Impl_, socket2_) -
               offsetof(Impl_, sysno_) +
               sizeof(Impl_::socket2_));

  // @@protoc_insertion_point(copy_constructor:gvisor.syscall.SocketPair)
}
PROTOBUF_NDEBUG_INLINE SocketPair::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void SocketPair::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, context_data_),
           0,
           offsetof(Impl_, socket2_) -
               offsetof(Impl_, context_data_) +
               sizeof(Impl_::socket2_));
}
SocketPair::~SocketPair() {
  // @@protoc_insertion_point(destructor:gvisor.syscall.SocketPair)
  SharedDtor(*this);
}
inline void SocketPair::SharedDtor(MessageLite& self) {
  SocketPair& this_ = static_cast<SocketPair&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.context_data_;
  delete this_._impl_.exit_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL SocketPair::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) SocketPair(arena);
}
constexpr auto SocketPair::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(SocketPair),
                                            alignof(SocketPair));
}
constexpr auto SocketPair::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_SocketPair_default_instance_._instance,
          &_table_.header,
          nullptr,  // IsInitialized
          &SocketPair::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<SocketPair>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &SocketPair::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<SocketPair>(), &SocketPair::ByteSizeLong,
              &SocketPair::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(SocketPair, _impl_._cached_size_),
          false,
      },
      &SocketPair::kDescriptorMethods,
      &descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull SocketPair_class_data_ =
        SocketPair::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SocketPair::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SocketPair_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(SocketPair_class_data_.tc_table);
  return SocketPair_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 8, 2, 0, 2>
SocketPair::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(SocketPair, _impl_._has_bits_),
    0, // no _extensions_
    8, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967040,  // skipmap
    offsetof(decltype(_table_), field_entries),
    8,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    SocketPair_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::gvisor::syscall::SocketPair>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // int32 socket2 = 8;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(SocketPair, _impl_.socket2_), 7>(),
     {64, 7, 0,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.socket2_)}},
    // .gvisor.common.ContextData context_data = 1;
    {::_pbi::TcParser::FastMtS1,
     {10, 0, 0,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.context_data_)}},
    // .gvisor.syscall.Exit exit = 2;
    {::_pbi::TcParser::FastMtS1,
     {18, 1, 1,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.exit_)}},
    // uint64 sysno = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(SocketPair, _impl_.sysno_), 2>(),
     {24, 2, 0,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.sysno_)}},
    // int32 domain = 4;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(SocketPair, _impl_.domain_), 3>(),
     {32, 3, 0,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.domain_)}},
    // int32 type = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(SocketPair, _impl_.type_), 4>(),
     {40, 4, 0,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.type_)}},
    // int32 protocol = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(SocketPair, _impl_.protocol_), 5>(),
     {48, 5, 0,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.protocol_)}},
    // int32 socket1 = 7;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(SocketPair, _impl_.socket1_), 6>(),
     {56, 6, 0,
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.socket1_)}},
  }}, {{
    65535, 65535
  }}, {{
    // .gvisor.common.ContextData context_data = 1;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.context_data_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // .gvisor.syscall.Exit exit = 2;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.exit_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // uint64 sysno = 3;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.sysno_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    // int32 domain = 4;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.domain_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 type = 5;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.type_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 protocol = 6;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.protocol_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 socket1 = 7;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.socket1_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // int32 socket2 = 8;
    {PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.socket2_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::gvisor::common::ContextData>()},
      {::_pbi::TcParser::GetTable<::gvisor::syscall::Exit>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void SocketPair::Clear() {
// @@protoc_insertion_point(message_clear_start:gvisor.syscall.SocketPair)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.context_data_ != nullptr);
      _impl_.context_data_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.exit_ != nullptr);
      _impl_.exit_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000fcU)) {
    ::memset(&_impl_.sysno_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.socket2_) -
        reinterpret_cast<char*>(&_impl_.sysno_)) + sizeof(_impl_.socket2_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL SocketPair::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const SocketPair& this_ = static_cast<const SocketPair&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL SocketPair::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const SocketPair& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:gvisor.syscall.SocketPair)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .gvisor.common.ContextData context_data = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.context_data_, this_._impl_.context_data_->GetCachedSize(), target,
        stream);
  }

  // .gvisor.syscall.Exit exit = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.exit_, this_._impl_.exit_->GetCachedSize(), target,
        stream);
  }

  // uint64 sysno = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_sysno() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_sysno(), target);
    }
  }

  // int32 domain = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_domain() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<4>(
              stream, this_._internal_domain(), target);
    }
  }

  // int32 type = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_type() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<5>(
              stream, this_._internal_type(), target);
    }
  }

  // int32 protocol = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_protocol() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<6>(
              stream, this_._internal_protocol(), target);
    }
  }

  // int32 socket1 = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_socket1() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<7>(
              stream, this_._internal_socket1(), target);
    }
  }

  // int32 socket2 = 8;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_socket2() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<8>(
              stream, this_._internal_socket2(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:gvisor.syscall.SocketPair)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t SocketPair::ByteSizeLong(const MessageLite& base) {
  const SocketPair& this_ = static_cast<const SocketPair&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t SocketPair::ByteSizeLong() const {
  const SocketPair& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:gvisor.syscall.SocketPair)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // .gvisor.common.ContextData context_data = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.context_data_);
    }
    // .gvisor.syscall.Exit exit = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.exit_);
    }
    // uint64 sysno = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_sysno() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sysno());
      }
    }
    // int32 domain = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_domain() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_domain());
      }
    }
    // int32 type = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_type() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_type());
      }
    }
    // int32 protocol = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_protocol() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_protocol());
      }
    }
    // int32 socket1 = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_socket1() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_socket1());
      }
    }
    // int32 socket2 = 8;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_socket2() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_socket2());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void SocketPair::MergeImpl(::google::protobuf::MessageLite& to_msg,
                            const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this =
      static_cast<SocketPair*>(&to_msg);
  auto& from = static_cast<const SocketPair&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:gvisor.syscall.SocketPair)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.context_data_ != nullptr);
      if (_this->_impl_.context_data_ == nullptr) {
        _this->_impl_.context_data_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.context_data_);
      } else {
        _this->_impl_.context_data_->MergeFrom(*from._impl_.context_data_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.exit_ != nullptr);
      if (_this->_impl_.exit_ == nullptr) {
        _this->_impl_.exit_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.exit_);
      } else {
        _this->_impl_.exit_->MergeFrom(*from._impl_.exit_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_sysno() != 0) {
        _this->_impl_.sysno_ = from._impl_.sysno_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_domain() != 0) {
        _this->_impl_.domain_ = from._impl_.domain_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_type() != 0) {
        _this->_impl_.type_ = from._impl_.type_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_protocol() != 0) {
        _this->_impl_.protocol_ = from._impl_.protocol_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_socket1() != 0) {
        _this->_impl_.socket1_ = from._impl_.socket1_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_socket2() != 0) {
        _this->_impl_.socket2_ = from._impl_.socket2_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void SocketPair::CopyFrom(const SocketPair& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:gvisor.syscall.SocketPair)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void SocketPair::InternalSwap(SocketPair* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.socket2_)
      + sizeof(SocketPair::_impl_.socket2_)
      - PROTOBUF_FIELD_OFFSET(SocketPair, _impl_.context_data_)>(
          reinterpret_cast<char*>(&_impl_.context_data_),
          reinterpret_cast<char*>(&other->_impl_.context_data_));
}

::google::protobuf::Metadata SocketPair::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace syscall
}  // namespace gvisor
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_pkg_2fsentry_2fseccheck_2fpoints_2fsyscall_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
